gc(); rm(list = ls()); set.seed(12345)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) 
# Note: if you are not using R Studio this command will not work, 
# set WD to source file location manually
require(magrittr)
require(plyr)
require(dplyr)
require(stringr)
require(data.table)
require(kableExtra)
source("../../function.R")
load("../../data/final/surveyexp_data_final.RData")

#### Subset to those that passed the manipulation check
list_manippass <- lapply(dfList, 
                         subset, 
                         manip_source == 1)

######################### ESTIMATE #####################################

## Get rid of enumerators with too few observations so you can use enum FE 
for(i in 1:length(list_manippass)){
  num_sbj <- tapply(list_manippass[[i]]$enum_id, 
                    list_manippass[[i]]$enum_id, 
                    length)
  enum_keep <- names(num_sbj[num_sbj >= 2])
  print(sum(!list_manippass[[i]]$enum_id %in% enum_keep)) 
  # This is the number of observations we lose
  list_manippass[[i]] <- 
    list_manippass[[i]][list_manippass[[i]]$enum_id %in% enum_keep, ]
}

results <- quick_lm(dep.vars = actionVars, 
                    dep.names = actionNames,
                    ind.vars = c(controlVars, feVars, treatVar), 
                    data = list_manippass, 
                    data.names = names(list_manippass),
                    keep.vars.tab = treatVar,
                    keep.vars.plot = treatVar,
                    inc.plot = F, 
                    subset.by = "dataset", 
                    stand.vars = "non-binary") 
# note that by default the standard error will be HC2, 
# you can change it by specifying "se_type = " as an argument in the quick_lm() 
# function. It will be passed to the lm_robust() function


## Table and plot

results$table <- results$table[order(results$table$outcome), ]

df_table_action <- results$table

df_table_action$dataset <- factor(df_table_action$dataset, 
                           levels = rev(c("Pooled", "Ghana", "Uganda"))) 

df_table_action$outcome <- factor(df_table_action$outcome, 
                           levels = rev(depNames))

kable(df_table_action[c(1,2,4,5,7)], digits = 3, "rst")

df_table_plot <- results$table
df_table_plot$Experiment <- factor(df_table_plot$dataset, 
                            levels = rev(c("Pooled", "Ghana", "Uganda"))) 
df_table_plot$outcome <- factor(df_table_plot$outcome, 
                         levels = rev(levels(results$table$outcome)))

# You can manipulate the order of the dvs etc when plotted by making them 
# factor variables and then setting the level order equal to the order you want
# them plotted in. Note that ggplot will order from bottom to top, so if 
# "action_avg" is the first level then it will be plotted at the very bottom

plot_action <- ggplot(df_table_plot, 
                      aes(y = estimate, 
                          x = outcome, 
                          colour = Experiment)) + 
  geom_linerange(aes(x = outcome, 
                     ymin = conf.low,
                     ymax = conf.high, 
                     size = I(10)), 
                 lwd = 1, 
                 linetype = 1, 
                 position = position_dodge(width = 3/4)) +
  geom_linerange(aes(x = outcome, 
                     ymin = estimate - std.error*qnorm(0.95),
                     ymax = estimate + std.error*qnorm(0.95), size = I(10)),
                 lwd = 1.8, linetype = 1, position = position_dodge(width = 3/4)) +
  geom_pointrange(aes( y = estimate, 
                       x = outcome, 
                       ymin =  conf.low,
                       ymax = conf.high),
                  lwd = 0.55, 
                  position = position_dodge(width = 3/4),
                  shape = 21, 
                  fill = "WHITE") + 
  geom_hline(yintercept = 0, 
             color = "grey0", 
             linetype = 2, 
             lwd = 0.5) +
  coord_flip() +  
  xlab("") + 
  theme_custom() +
  theme(legend.position = c(.86, .18), 
        plot.title = element_text(hjust = 0, vjust = 2.12), 
        legend.text = element_text(size=12), 
        axis.text.y = (element_text(face = c("plain", "plain", "plain", "plain", 
                                             "plain", "plain", "plain", "plain", 
                                             "plain", "bold")))) + 
  ylab("Change in Standard Deviation Units") +
  scale_color_manual(values = c("gray67", "gray45", "grey0"), 
                     guide = guide_legend(reverse = TRUE)) + 
  ylim(-.35, .35)

(plot_action_final <- plot_action + 
    annotate("rect", ymin = 1.5*min(df_table_plot$conf.low[1:3]), 
                              ymax = 1.5*max(df_table_plot$conf.high[1:3]), 
                              xmin = 9.5, xmax = 10.5, 
                              alpha = 0.1, fill = "black"))

pdf(file = "../../figures/appendix/figc2.pdf", height = 6, width = 10)
print(plot_action_final)
dev.off()
