gc(); rm(list = ls()); set.seed(12345)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) 
# Note: if you are not using R Studio this command will not work, 
# set WD to source file location manually
require(magrittr)
require(plyr)
require(dplyr)
require(stringr)
require(data.table)
require(kableExtra)
source("../../function.R")
load("../../data/final/lab_data_final.RData")

######################### Subset to those who passed the manipulation check ####
list_manippass <- lapply(dfList, 
                         subset, 
                         manip_source == 1)

## Estimate

results <- quick_lm(dep.vars = depVars, 
                    dep.names = depNames,
                    ind.vars = c(controlVars, feVars, treatVar), 
                    data = list_manippass, 
                    keep.vars.tab = treatVar,
                    keep.vars.plot = treatVar,
                    inc.plot = F, 
                    data.names = names(list_manippass),
                    subset.by = "dataset", 
                    stand.vars = depVars, 
                    se_type = "CR2",
                    cluster = sym("sbj_unique")) # note that by default the standard error will be HC2, you can change it by specifying "se_type = " as an argument in the quick_lm() function. It will be passed to the lm_robust() function


## Table and plot 

require('texreg')

df_table_lab <- results$table

df_table_lab$dataset <- factor(df_table_lab$dataset, 
                        levels = rev(c("Uganda June 2017", 
                                       "Uganda January 2017", 
                                       "Ghana July 2016", 
                                       "Pooled"))) 

df_table_lab$outcome <- factor(df_table_lab$outcome, 
                        levels = rev(depVars))

kable(results$table[, c(1,4,5,7)], digits = 3, "rst")

plot_lab_punthresh <- results$table

plot_lab_punthresh$Experiment <- factor(plot_lab_punthresh$dataset, 
                            levels = (c("Uganda June 2017", 
                                        "Uganda January 2017", 
                                        "Ghana July 2016", 
                                        "Pooled"))) 

plot_lab_punthresh$outcome <- factor(plot_lab_punthresh$outcome, 
                         levels = ((levels(results$table$outcome)))) 
# You can manipulate the order of the dvs etc when plotted by making them 
# factor variables and then setting the level order equal to the order you want 
# them plotted in. Note that ggplot will order from bottom to top, so if 
# "action_avg" is the first level then it will be plotted at the very bottom

(plot_lab_punthresh_final <- ggplot(plot_lab_punthresh, 
                                    aes(y = estimate, 
                                        x = outcome, 
                                        colour = Experiment)) + 
        geom_linerange(aes(x = outcome, 
                           ymin = conf.low,
                           ymax = conf.high, 
                           size = I(10)),
                       lwd = 1, 
                       linetype = 1, 
                       position = position_dodge(width = 1/2)) +
        geom_linerange(aes(x = outcome, 
                           ymin = estimate - std.error*qnorm(0.95),
                           ymax = estimate + std.error*qnorm(0.95), 
                           size = I(10)),
                       lwd = 1.8, 
                       linetype = 1, 
                       position = position_dodge(width = 1/2)) +
        geom_pointrange(aes( y = estimate, 
                             x = outcome, 
                             ymin =  conf.low,
                             ymax = conf.high),
                        lwd = 0.65, 
                        position = position_dodge(width = 1/2),
                        shape = 21, 
                        fill = "WHITE") + 
        geom_hline(yintercept = 0, 
                   color = "grey0", 
                   linetype = 2, 
                   lwd = 0.5) +
        coord_flip() +  
        xlab(" ") + 
        ylab("Change in Punishment Threshold* \n (Baseline = Oil Condition)") +
        theme_custom(axis_text_size = 12) + 
        theme(legend.position = c(.25, .55), 
              legend.title = element_text(size = 10), 
              legend.text = element_text(size = 10),
              plot.title = element_text(size = 13, 
                                        hjust = 0, 
                                        vjust = 2.12)) + 
        scale_color_manual(values = rev(c("black", 
                                          "gray25", 
                                          "gray50", 
                                          "gray75")), 
                           labels = rev(c("Pooled", 
                                          "Ghana July 2016", 
                                          "Uganda January 2017",
                                          "Uganda June 2017")), 
                           guide = guide_legend(reverse = TRUE)) +
        ylim(-.8, .8) + 
                ggtitle("Lab Experiments"))

pdf("../../figures/appendix/figc3.pdf", 
    height = 6, 
    width = 8)

print(plot_lab_punthresh_final)

dev.off()
