gc(); rm(list = ls()); set.seed(12345)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) 
# Note: if you are not using R Studio this command will not work, 
# set WD to source file location manually
require(magrittr)
require(plyr)
require(dplyr)
require(stringr)
require(data.table)
require(kableExtra)
source("../../function.R")
load("../../data/final/surveyexp_data_final.RData") 

######################### Subset to those who passed the manipulation check ####
list_field_manippass <- lapply(dfList, 
                               function(x)x[x$manip_source ==1, ])


######################### ESTIMATE #############################################
## Get rid of enumerators with less than 3 observations (this is the minimum threshold
## needed to allow estimation using the lm_robust() function)
for(i in 1:length(list_field_manippass)){
  num_sbj <- tapply(list_field_manippass[[i]]$enum_id, 
                    list_field_manippass[[i]]$enum_id, 
                    length)
  enum_keep <- names(num_sbj[num_sbj >= 3])
  list_field_manippass[[i]] <- 
    list_field_manippass[[i]][list_field_manippass[[i]]$enum_id %in% enum_keep, ]
}
 
results <- quick_lm(dep.vars = depVars, 
                    dep.names = depNames,
                    ind.vars = c(controlVars, feVars, treatVar), 
                    data = list_field_manippass, 
                    keep.vars.tab = treatVar,
                    keep.vars.plot = treatVar,
                    stand.vars = "non-binary") 
# note that by default the standard error will be HC2, 
# you can change it by specifying "se_type = " as an argument 
# in the quick_lm() function. It will be passed to the lm_robust() function

results$table$dataset <- mapvalues(results$table$dataset, 
                                   from = c("dataset1", 
                                            "dataset2", 
                                            "dataset3"), 
                                   to = c("Pooled", 
                                          "Uganda", 
                                          "Ghana"))

results$table$family <- NA
results$table$family[results$table$outcome %in% c("Action Index (NMWI)",
                                                  "Create Agency",
                                                  "Willing to Send SMS",
                                                  "Sent SMS",
                                                  "Donated (Binary)",
                                                  "Taxes Willing to Commit (Binary)",
                                                  "Signed Petition (Any)",
                                                  "Pr(Contact Village Elder)",
                                                  "Pr(Contact Local Official)",
                                                  "Pr(Contact MP)")] <- "Action" 
# Create "family" variable to subset with later

results$table$family[results$table$outcome %in% 
                       c("Misappropriation Index (NMWI)", 
                         "Pr(Used for Clientelism)", 
                         "Pr(Spending Hidden)", 
                         "Pr(MP Observes Spending)")] <- "Misappropriation"

results$table$family[results$table$outcome %in% c("Benefit Index (NMWI)",
                                                  "Funds Benefit Family",
                                                  "Funds Benefit Community",
                                                  "Funds Benefit Ordinary People",
                                                  "Funds Split Equally")] <- "Benefit"

results$table <- results$table[order(results$table$outcome), ]


#"Benefit" Family Dependent Variables


df_table_benefit <- results$table[results$table$family == "Benefit", ]



df_table_benefit$dataset <- factor(df_table_benefit$dataset, 
                           levels = rev(c("Pooled", 
                                          "Ghana", 
                                          "Uganda")))

df_table_benefit$outcome <- factor(df_table_benefit$outcome, 
                           levels = rev(c("Benefit Index (NMWI)",
                                          "Funds Benefit Family",
                                          "Funds Benefit Community",
                                          "Funds Benefit Ordinary People",
                                          "Funds Split Equally")))


kable(results$table[results$table$family == "Benefit", 
                    c(2,1,4,5,7)], 
      digits = 3, "rst")


######################## VISUALIZE #################################

############ Benefit

df_table_plot <- results$table[results$table$family == "Benefit", ]

## Format the data frame for plotting

df_table_plot$Experiment <- factor(df_table_plot$dataset, 
                             levels = rev(c("Pooled", 
                                            "Ghana", 
                                            "Uganda")))

df_table_plot$outcome <- factor(df_table_plot$outcome, 
                          levels = rev(levels(results$table$outcome)))
# You can manipulate the order of the dvs etc when plotted by making them 
# factor variables and then setting the level order equal to the order you 
# want them plotted in. Note that ggplot will order from bottom to top, so 
# if "action_avg" is the first level then it will be plotted at the very bottom

plot_benefit <- ggplot(df_table_plot, 
                       aes(y = estimate, 
                           x = outcome, 
                           colour = Experiment)) + 
  geom_linerange(aes(x = outcome, 
                     ymin = conf.low,
                     ymax = conf.high, 
                     size = I(10)),
                 lwd = 1, 
                 linetype = 1, 
                 position = position_dodge(width = 3/4)) +
  geom_linerange(aes(x = outcome, 
                     ymin = estimate - std.error*qnorm(0.95),
                     ymax = estimate + std.error*qnorm(0.95), 
                     size = I(10)),
                 lwd = 1.8, 
                 linetype = 1, 
                 position = position_dodge(width = 3/4)) +
  geom_pointrange(aes( y = estimate, 
                       x = outcome, 
                       ymin =  conf.low,
                       ymax = conf.high),
                  lwd = 0.55, 
                  position = position_dodge(width = 3/4),
                  shape = 21, 
                  fill = "WHITE") + 
  geom_hline(yintercept = 0, 
             color = "grey0", 
             linetype = 2, 
             lwd = 0.5) +
  coord_flip() +  
  xlab("") + 
  theme_custom() +
  theme(legend.position = c(.86, .18)) + 
  ylab("Change in Standard Deviation Units") +
  scale_color_manual(values = c("gray67", 
                                "gray45", 
                                "grey0"), 
                     guide = guide_legend(reverse = TRUE)) + 
  ylim(-.35, .35)



pdf(file = "../../figures/appendix/figc4.pdf", 
    height = 6, 
    width = 10)

print(plot_benefit)
dev.off()
