gc(); rm(list = ls()); set.seed(12345)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) # Note: if you are not using R Studio this command will not work, set WD to source file location manually
require(magrittr)
require(plyr)
require(dplyr)
require(stringr)
require(data.table)
require(kableExtra)
source("../../function.R") 
load("../../data/final/surveyexp_data_final.RData")


############ Create heterogeneity test variables (Female, Quality of Public Svc, Corruption)

for(i in 1:length(dfList)){
  dfList[[i]] <- mutate(dfList[[i]], male = ifelse((dfList[[i]]$female==0),1,0))
  dfList[[i]] <- mutate(dfList[[i]], services_low = ifelse((dfList[[i]]$services_high==0),1,0))
  dfList[[i]] <- mutate(dfList[[i]], corr_low = ifelse((dfList[[i]]$corr_high==0),1,0))
}


########### Subset to Ghana Data

dfList <- dfList$Ghana
dfList <- dfList[c(actionVars, depVars, treatVar, controlVars, feVars, "female", "male", 
                   "services_high", "services_low",
                   "corr_high", "corr_low")]

## Drop enumerators with less than 4 observations
## This is the minimum threshold needed to allow estimation using the lm_robust() function

dfList1 <- subset(dfList, female==1)
numSbj <- tapply(dfList1$enum_id, dfList1$enum_id, length)
enumKeep <- names(numSbj[numSbj >= 4])
dfList1 <- dfList1[dfList1$enum_id %in% enumKeep, ]

dfList2 <- subset(dfList, male==1)
numSbj <- tapply(dfList2$enum_id, dfList2$enum_id, length)
enumKeep <- names(numSbj[numSbj >= 4])
dfList2 <- dfList2[dfList2$enum_id %in% enumKeep, ]

dfList3 <- subset(dfList, services_high==1)
numSbj <- tapply(dfList3$enum_id, dfList3$enum_id, length)
enumKeep <- names(numSbj[numSbj >= 4])
dfList3 <- dfList3[dfList3$enum_id %in% enumKeep, ]

dfList4 <- subset(dfList, services_low==1)
numSbj <- tapply(dfList4$enum_id, dfList4$enum_id, length)
enumKeep <- names(numSbj[numSbj >= 4])
dfList4 <- dfList4[dfList4$enum_id %in% enumKeep, ]

dfList5 <- subset(dfList, corr_high==1)
numSbj <- tapply(dfList5$enum_id, dfList5$enum_id, length)
enumKeep <- names(numSbj[numSbj >= 4])
dfList5 <- dfList5[dfList5$enum_id %in% enumKeep, ]

dfList6 <- subset(dfList, corr_low==1)
numSbj <- tapply(dfList6$enum_id, dfList6$enum_id, length)
enumKeep <- names(numSbj[numSbj >= 4])
dfList6 <- dfList6[dfList6$enum_id %in% enumKeep, ]


########### Creating appropriate control variables

controlsex <- controlVars[c(1,2,4,5)]
controlserv <- controlVars[c(1:3, 5)]

######################### ESTIMATE #####################################

######### Female Ghana

results1 <- quick_lm(dep.vars = actionVars, 
                    dep.names = actionNames,
                    ind.vars = c(controlsex, feVars, treatVar), 
                    data = dfList1, 
                    keep.vars.tab = treatVar,
                    keep.vars.plot = treatVar,
                    inc.plot = F, 
                    subset.by = "dataset", 
                    stand.vars = "non-binary") # note that by default the standard error will be HC2, you can change it by specifying "se_type = " as an argument in the quick_lm() function. It will be passed to the lm_robust() function

results1$table$dataset <- mapvalues(results1$table$dataset, 
                                   from = c("dataset1"), 
                                   to = c("Ghana"))
results1$table$family <- NA
results1$table$family[results1$table$outcome %in% c("Action Index (NMWI)",
                                                  "Create Agency",
                                                  "Willing to Send SMS",
                                                  "Sent SMS",
                                                  "Donated (Binary)",
                                                  "Taxes Willing to Commit (Binary)",
                                                  "Signed Petition (Any)",
                                                  "Pr(Contact Village Elder)",
                                                  "Pr(Contact Local Official)",
                                                  "Pr(Contact MP)")] <- "Action" # Create "family" variable to subset with later
results1$table <- results1$table[order(results1$table$outcome),]

#"Action" Family Dependent Variables

ExpInc <- c("Ghana")
dfAction1 <- results1$table[results1$table$family == "Action", ]
dfAction1$dataset <- factor(dfAction1$dataset, 
                           levels = rev(c("Ghana"))) 
dfAction1$outcome <- factor(dfAction1$outcome, 
                           levels = rev(c("Action Index (NMWI)",
                                          "Create Agency",
                                          "Willing to Send SMS",
                                          "Sent SMS",
                                          "Donated (Binary)",
                                          "Taxes Willing to Commit (Binary)",
                                          "Signed Petition (Any)",
                                          "Pr(Contact Village Elder)",
                                          "Pr(Contact Local Official)",
                                          "Pr(Contact MP)")))
(dfUse1 <- dfAction1 %>%
    filter(dfAction1$family == "Action"))
dfUse1 <- dfUse1[c(1,2,4,5,7)]
het1 <- dfAction1[, c(2,4,5,7)]
het1 <- het1 %>% 
  mutate_if(is.numeric, round, digits=3)

######### Male Ghana

results2 <- quick_lm(dep.vars = actionVars, 
                     dep.names = actionNames,
                     ind.vars = c(controlsex, feVars, treatVar), 
                     data = dfList2, 
                     keep.vars.tab = treatVar,
                     keep.vars.plot = treatVar,
                     inc.plot = F, 
                     subset.by = "dataset", 
                     stand.vars = "non-binary") # note that by default the standard error will be HC2, you can change it by specifying "se_type = " as an argument in the quick_lm() function. It will be passed to the lm_robust() function

results2$table$dataset <- mapvalues(results2$table$dataset, 
                                    from = c("dataset1"), 
                                    to = c("Ghana"))
results2$table$family <- NA
results2$table$family[results2$table$outcome %in% c("Action Index (NMWI)",
                                                    "Create Agency",
                                                    "Willing to Send SMS",
                                                    "Sent SMS",
                                                    "Donated (Binary)",
                                                    "Taxes Willing to Commit (Binary)",
                                                    "Signed Petition (Any)",
                                                    "Pr(Contact Village Elder)",
                                                    "Pr(Contact Local Official)",
                                                    "Pr(Contact MP)")] <- "Action" # Create "family" variable to subset with later


results2$table <- results2$table[order(results2$table$outcome),]


#"Action" Family Dependent Variables

ExpInc <- c("Ghana")
dfAction2 <- results2$table[results2$table$family == "Action", ]
dfAction2$dataset <- factor(dfAction2$dataset, 
                            levels = rev(c("Ghana"))) 
dfAction2$outcome <- factor(dfAction2$outcome, 
                            levels = rev(c("Action Index (NMWI)",
                                           "Create Agency",
                                           "Willing to Send SMS",
                                           "Sent SMS",
                                           "Donated (Binary)",
                                           "Taxes Willing to Commit (Binary)",
                                           "Signed Petition (Any)",
                                           "Pr(Contact Village Elder)",
                                           "Pr(Contact Local Official)",
                                           "Pr(Contact MP)")))
(dfUse2 <- dfAction2 %>%
    filter(dfAction2$family == "Action"))
dfUse2 <- dfUse2[c(1,2,4,5,7)]
het2 <- dfAction2[, c(2,4,5,7)]
het2 <- het2 %>% 
  mutate_if(is.numeric, round, digits=3)

############# Services High Ghana

results3 <- quick_lm(dep.vars = actionVars, 
                     dep.names = actionNames,
                     ind.vars = c(controlserv, feVars, treatVar), 
                     data = dfList3, 
                     keep.vars.tab = treatVar,
                     keep.vars.plot = treatVar,
                     inc.plot = F, 
                     subset.by = "dataset", 
                     stand.vars = "non-binary") # note that by default the standard error will be HC3, you can change it by specifying "se_type = " as an argument in the quick_lm() function. It will be passed to the lm_robust() function

results3$table$dataset <- mapvalues(results3$table$dataset, 
                                    from = c("dataset1"), 
                                    to = c("Ghana"))
results3$table$family <- NA
results3$table$family[results3$table$outcome %in% c("Action Index (NMWI)",
                                                    "Create Agency",
                                                    "Willing to Send SMS",
                                                    "Sent SMS",
                                                    "Donated (Binary)",
                                                    "Taxes Willing to Commit (Binary)",
                                                    "Signed Petition (Any)",
                                                    "Pr(Contact Village Elder)",
                                                    "Pr(Contact Local Official)",
                                                    "Pr(Contact MP)")] <- "Action" # Create "family" variable to subset with later


results3$table <- results3$table[order(results3$table$outcome),]


#"Action" Family Dependent Variables

ExpInc <- c("Ghana")
dfAction3 <- results3$table[results3$table$family == "Action", ]
dfAction3$dataset <- factor(dfAction3$dataset, 
                            levels = rev(c("Ghana"))) 
dfAction3$outcome <- factor(dfAction3$outcome, 
                            levels = rev(c("Action Index (NMWI)",
                                           "Create Agency",
                                           "Willing to Send SMS",
                                           "Sent SMS",
                                           "Donated (Binary)",
                                           "Taxes Willing to Commit (Binary)",
                                           "Signed Petition (Any)",
                                           "Pr(Contact Village Elder)",
                                           "Pr(Contact Local Official)",
                                           "Pr(Contact MP)")))
(dfUse3 <- dfAction3 %>%
    filter(dfAction3$family == "Action"))
dfUse3 <- dfUse3[c(1,2,4,5,7)]
het3 <- dfAction3[, c(2,4,5,7)]
het3 <- het3 %>% 
  mutate_if(is.numeric, round, digits=3)

################ Services Low Ghana

results4 <- quick_lm(dep.vars = actionVars, 
                     dep.names = actionNames,
                     ind.vars = c(controlserv, feVars, treatVar), 
                     data = dfList4, 
                     keep.vars.tab = treatVar,
                     keep.vars.plot = treatVar,
                     inc.plot = F, 
                     subset.by = "dataset", 
                     stand.vars = "non-binary") # note that by default the standard error will be HC4, you can change it by specifying "se_type = " as an argument in the quick_lm() function. It will be passed to the lm_robust() function
results4$table$dataset <- mapvalues(results4$table$dataset, 
                                    from = c("dataset1"), 
                                    to = c("Ghana"))
results4$table$family <- NA
results4$table$family[results4$table$outcome %in% c("Action Index (NMWI)",
                                                    "Create Agency",
                                                    "Willing to Send SMS",
                                                    "Sent SMS",
                                                    "Donated (Binary)",
                                                    "Taxes Willing to Commit (Binary)",
                                                    "Signed Petition (Any)",
                                                    "Pr(Contact Village Elder)",
                                                    "Pr(Contact Local Official)",
                                                    "Pr(Contact MP)")] <- "Action" # Create "family" variable to subset with later
results4$table <- results4$table[order(results4$table$outcome),]


#"Action" Family Dependent Variables

ExpInc <- c("Ghana")
dfAction4 <- results4$table[results4$table$family == "Action", ]
dfAction4$dataset <- factor(dfAction4$dataset, 
                            levels = rev(c("Ghana"))) 
dfAction4$outcome <- factor(dfAction4$outcome, 
                            levels = rev(c("Action Index (NMWI)",
                                           "Create Agency",
                                           "Willing to Send SMS",
                                           "Sent SMS",
                                           "Donated (Binary)",
                                           "Taxes Willing to Commit (Binary)",
                                           "Signed Petition (Any)",
                                           "Pr(Contact Village Elder)",
                                           "Pr(Contact Local Official)",
                                           "Pr(Contact MP)")))
(dfUse4 <- dfAction4 %>%
    filter(dfAction4$family == "Action"))
dfUse4 <- dfUse4[c(1,2,4,5,7)]
het4 <- dfAction4[, c(2,4,5,7)]
het4 <- het4 %>% 
  mutate_if(is.numeric, round, digits=3)

################## Corruption High Ghana

results5 <- quick_lm(dep.vars = actionVars, 
                     dep.names = actionNames,
                     ind.vars = c(controlVars, feVars, treatVar), 
                     data = dfList5, 
                     keep.vars.tab = treatVar,
                     keep.vars.plot = treatVar,
                     inc.plot = F, 
                     subset.by = "dataset", 
                     stand.vars = "non-binary") # note that by default the standard error will be HC5, you can change it by specifying "se_type = " as an argument in the quick_lm() function. It will be passed to the lm_robust() function
results5$table$dataset <- mapvalues(results5$table$dataset, 
                                    from = c("dataset1"), 
                                    to = c("Ghana"))
results5$table$family <- NA
results5$table$family[results5$table$outcome %in% c("Action Index (NMWI)",
                                                    "Create Agency",
                                                    "Willing to Send SMS",
                                                    "Sent SMS",
                                                    "Donated (Binary)",
                                                    "Taxes Willing to Commit (Binary)",
                                                    "Signed Petition (Any)",
                                                    "Pr(Contact Village Elder)",
                                                    "Pr(Contact Local Official)",
                                                    "Pr(Contact MP)")] <- "Action" # Create "family" variable to subset with later


results5$table <- results5$table[order(results5$table$outcome),]

#"Action" Family Dependent Variables

ExpInc <- c("Ghana")
dfAction5 <- results5$table[results5$table$family == "Action", ]
dfAction5$dataset <- factor(dfAction5$dataset, 
                            levels = rev(c("Ghana"))) 
dfAction5$outcome <- factor(dfAction5$outcome, 
                            levels = rev(c("Action Index (NMWI)",
                                           "Create Agency",
                                           "Willing to Send SMS",
                                           "Sent SMS",
                                           "Donated (Binary)",
                                           "Taxes Willing to Commit (Binary)",
                                           "Signed Petition (Any)",
                                           "Pr(Contact Village Elder)",
                                           "Pr(Contact Local Official)",
                                           "Pr(Contact MP)")))
(dfUse5 <- dfAction5 %>%
    filter(dfAction5$family == "Action"))
dfUse5 <- dfUse5[c(1,2,4,5,7)]
het5 <- dfAction5[, c(2,4,5,7)]
het5 <- het5 %>% 
  mutate_if(is.numeric, round, digits=3)

################## Corruption High Ghana

results6 <- quick_lm(dep.vars = actionVars, 
                     dep.names = actionNames,
                     ind.vars = c(controlVars, feVars, treatVar), 
                     data = dfList6, 
                     keep.vars.tab = treatVar,
                     keep.vars.plot = treatVar,
                     inc.plot = F, 
                     subset.by = "dataset", 
                     stand.vars = "non-binary") # note that by default the standard error will be HC6, you can change it by specifying "se_type = " as an argument in the quick_lm() function. It will be passed to the lm_robust() function
results6$table$dataset <- mapvalues(results6$table$dataset, 
                                    from = c("dataset1"), 
                                    to = c("Ghana"))
results6$table$family <- NA
results6$table$family[results6$table$outcome %in% c("Action Index (NMWI)",
                                                    "Create Agency",
                                                    "Willing to Send SMS",
                                                    "Sent SMS",
                                                    "Donated (Binary)",
                                                    "Taxes Willing to Commit (Binary)",
                                                    "Signed Petition (Any)",
                                                    "Pr(Contact Village Elder)",
                                                    "Pr(Contact Local Official)",
                                                    "Pr(Contact MP)")] <- "Action" # Create "family" variable to subset with later


results6$table <- results6$table[order(results6$table$outcome),]


#"Action" Family Dependent Variables

ExpInc <- c("Ghana")
dfAction6 <- results6$table[results6$table$family == "Action", ]
dfAction6$dataset <- factor(dfAction6$dataset, 
                            levels = rev(c("Ghana"))) 
dfAction6$outcome <- factor(dfAction6$outcome, 
                            levels = rev(c("Action Index (NMWI)",
                                           "Create Agency",
                                           "Willing to Send SMS",
                                           "Sent SMS",
                                           "Donated (Binary)",
                                           "Taxes Willing to Commit (Binary)",
                                           "Signed Petition (Any)",
                                           "Pr(Contact Village Elder)",
                                           "Pr(Contact Local Official)",
                                           "Pr(Contact MP)")))
(dfUse6 <- dfAction6 %>%
    filter(dfAction6$family == "Action"))
dfUse6 <- dfUse6[c(1,2,4,5,7)]

het6 <- dfAction6[, c(2,4,5,7)]

het6 <- het6 %>% 
  mutate_if(is.numeric, round, digits=3)

############## Combining heterogeneity test variables into a combined format

tabc5 <- cbind(het1, het2, het3, het4, het5, het6)
tabc5 <- tabc5[, c(1:4, 6:8, 10:12, 14:16, 18:20, 22:24)]
dt <- tabc5[,c(1:4, 5:7, 8:10, 11:13, 14:16, 17:19)]

kable(dt, format = "latex", booktabs = T, caption = "Table C13") %>%
  kable_styling(latex_options = c("striped", "hold_position"),
                full_width = F) %>%
  add_header_above(c(" ", "Female" = 3, "Male" = 3, "Services High" = 3, "Services Low" = 3, "Corrupt High" = 3,
                     "Corrupt Low" = 3))
