gc(); rm(list = ls()); set.seed(12345)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) # Note: if you are not using R Studio this command will not work, set WD to source file location manually
require(magrittr)
require(plyr)
require(dplyr)
require(stringr)
require(data.table)
require(kableExtra)
require(stargazer)
source("../../function.R") 
load("../../data/final/lab_data_final.RData") 


############ Create heterogeneity test variables (Age, Education)

for(i in 1:length(dfList)){
  dfList[[i]] <- mutate(dfList[[i]], age_20_35 = ifelse((dfList[[i]]$age>20 & dfList[[i]]$age<35),1,0))
  dfList[[i]] <- mutate(dfList[[i]], age_35_50 = ifelse((dfList[[i]]$age>=35 & dfList[[i]]$age<50),1,0))
  dfList[[i]] <- mutate(dfList[[i]], age_50p = ifelse((dfList[[i]]$age>=50),1,0))
}

quantile(dfList$`Ghana July 2016`$edu, na.rm = TRUE)

dfList$`Ghana July 2016` <- mutate(dfList$`Ghana July 2016`, edu_high = ifelse((dfList$`Ghana July 2016`$edu>4),1,0))
dfList$`Ghana July 2016` <- mutate(dfList$`Ghana July 2016`, edu_low = ifelse((dfList$`Ghana July 2016`$edu<=4),1,0))

quantile(dfList$`Uganda January 2017`$edu, na.rm = TRUE)

dfList$`Uganda January 2017` <- mutate(dfList$`Uganda January 2017`, edu_high = ifelse((dfList$`Uganda January 2017`$edu>3),1,0))
dfList$`Uganda January 2017` <- mutate(dfList$`Uganda January 2017`, edu_low = ifelse((dfList$`Uganda January 2017`$edu<=3),1,0))


quantile(dfList$`Uganda June 2017`$edu, na.rm = TRUE)

dfList$`Uganda June 2017` <- mutate(dfList$`Uganda June 2017`, edu_high = ifelse((dfList$`Uganda June 2017`$edu>12),1,0))
dfList$`Uganda June 2017` <- mutate(dfList$`Uganda June 2017`, edu_low = ifelse((dfList$`Uganda June 2017`$edu<=12),1,0))


quantile(dfList$Pooled$edu, na.rm = TRUE)
dfList$Pooled <- mutate(dfList$Pooled, edu_high = ifelse((dfList$Pooled$edu>4),1,0))
dfList$Pooled <- mutate(dfList$Pooled, edu_low = ifelse((dfList$Pooled$edu<=4),1,0))








dfList <- lapply(dfList, function(x) x[(names(x) %in% c(clusterVars, depVars, treatVar, controlVars, feVars, "age_20_35", "age_35_50",
                                                        "age_50p", "edu_high", "edu_low"))])


## Drop enumerators with less than 2 observations
## This is the minimum threshold needed to allow estimation using the lm_robust() function

dfList1 <- lapply(dfList, subset, age_20_35==1)
for(i in 1:length(dfList1)){
  
  numSbj <- tapply(dfList1[[i]]$enum_id, dfList1[[i]]$enum_id, length)
enumKeep <- names(numSbj[numSbj >= 2])
dfList1[[i]] <- dfList1[[i]][dfList1[[i]]$enum_id %in% enumKeep, ]
}

dfList2 <- lapply(dfList, subset, age_35_50==1)
for(i in 1:length(dfList2)){
  
  numSbj <- tapply(dfList2[[i]]$enum_id, dfList2[[i]]$enum_id, length)
  enumKeep <- names(numSbj[numSbj >= 2])
  dfList2[[i]] <- dfList2[[i]][dfList2[[i]]$enum_id %in% enumKeep, ]
}

dfList3 <- lapply(dfList, subset, age_50p==1)
for(i in 1:length(dfList3)){
  
  numSbj <- tapply(dfList3[[i]]$enum_id, dfList3[[i]]$enum_id, length)
  enumKeep <- names(numSbj[numSbj >= 2])
  dfList3[[i]] <- dfList3[[i]][dfList3[[i]]$enum_id %in% enumKeep, ]
}

dfList4 <- lapply(dfList, subset, edu_high==1)
for(i in 1:length(dfList4)){
  
  numSbj <- tapply(dfList4[[i]]$enum_id, dfList4[[i]]$enum_id, length)
  enumKeep <- names(numSbj[numSbj >= 2])
  dfList4[[i]] <- dfList4[[i]][dfList4[[i]]$enum_id %in% enumKeep, ]
}

dfList5 <- lapply(dfList, subset, edu_low==1)
for(i in 1:length(dfList5)){
  
  numSbj <- tapply(dfList5[[i]]$enum_id, dfList5[[i]]$enum_id, length)
  enumKeep <- names(numSbj[numSbj >= 2])
  dfList5[[i]] <- dfList5[[i]][dfList5[[i]]$enum_id %in% enumKeep, ]
}

######################## Create appropriate control variables ##################

controlsage <- controlVars[c(2:5)]
controlsedu <- controlVars[c(1, 3:5)]

######################### ESTIMATE #############################################

######### Age 20-35 Pooled
results1 <- quick_lm(dep.vars = depVars, 
                    dep.names = depNames,
                    ind.vars = c(controlsage, feVars, treatVar), 
                    data = dfList1, 
                    keep.vars.tab = treatVar,
                    keep.vars.plot = treatVar,
                    inc.plot = F, 
                    data.names = names(dfList1),
                    subset.by = "dataset", 
                    stand.vars = depVars, 
                    se_type = "CR2",
                    cluster = sym("sbj_unique")) # note that by default the standard error will be HC2, you can change it by specifying "se_type = " as an argument in the quick_lm() function. It will be passed to the lm_robust() function
results1$table <- results1$table[order(results1$table$outcome),]
dfLab1 <- results1$table
dfLab1$dataset <- factor(dfLab1$dataset, 
                        levels = rev(c("Uganda June 2017", "Uganda January 2017", "Ghana July 2016", 
                                       "Pooled"))) 
dfLab1$outcome <- factor(dfLab1$outcome, 
                        levels = rev(depVars))
het1 <- dfLab1[, c(1,4,5,7)]
het1 <- het1 %>% 
  mutate_if(is.numeric, round, digits=3)

######### Age 35-50 Pooled

results2 <- quick_lm(dep.vars = depVars, 
                     dep.names = depNames,
                     ind.vars = c(controlsage, feVars, treatVar), 
                     data = dfList2, 
                     keep.vars.tab = treatVar,
                     keep.vars.plot = treatVar,
                     inc.plot = F, 
                     data.names = names(dfList2),
                     subset.by = "dataset", 
                     stand.vars = depVars, 
                     se_type = "CR2",
                     cluster = sym("sbj_unique")) # note that by default the standard error will be HC2, you can change it by specifying "se_type = " as an argument in the quick_lm() function. It will be passed to the lm_robust() function
results2$table <- results2$table[order(results2$table$outcome),]
dfLab2 <- results2$table
dfLab2$dataset <- factor(dfLab2$dataset, 
                         levels = rev(c("Uganda June 2017", "Uganda January 2017", "Ghana July 2016", 
                                        "Pooled"))) 
dfLab2$outcome <- factor(dfLab2$outcome, 
                         levels = rev(depVars))
het2 <- dfLab2[, c(1,4,5,7)]
het2 <- het2 %>% 
  mutate_if(is.numeric, round, digits=3)

############# Age 50+ Pooled

#Uganda June 2017 estimates can be disregarded, not enough observations

results3 <- quick_lm(dep.vars = depVars, 
                     dep.names = depNames,
                     ind.vars = c(controlsage, feVars, treatVar), 
                     data = dfList3, 
                     keep.vars.tab = treatVar,
                     keep.vars.plot = treatVar,
                     inc.plot = F, 
                     data.names = names(dfList3),
                     subset.by = "dataset", 
                     stand.vars = depVars, 
                     se_type = "CR2",
                     cluster = sym("sbj_unique")) # note that by default the standard error will be HC2, you can change it by specifying "se_type = " as an argument in the quick_lm() function. It will be passed to the lm_robust() function




results3$table <- results3$table[order(results3$table$outcome),]
dfLab3 <- results3$table
dfLab3$dataset <- factor(dfLab3$dataset, 
                         levels = rev(c("Uganda January 2017", "Ghana July 2016", 
                                        "Pooled"))) 
dfLab3$outcome <- factor(dfLab3$outcome, 
                         levels = rev(depVars))
het3 <- dfLab3[, c(1,4,5,7)]
het3 <- het3 %>% 
  mutate_if(is.numeric, round, digits=3)

################ High Ed Pooled

results4 <- quick_lm(dep.vars = depVars, 
                     dep.names = depNames,
                     ind.vars = c(controlsedu, feVars, treatVar), 
                     data = dfList4, 
                     keep.vars.tab = treatVar,
                     keep.vars.plot = treatVar,
                     inc.plot = F, 
                     data.names = names(dfList4),
                     subset.by = "dataset", 
                     stand.vars = depVars, 
                     se_type = "CR2",
                     cluster = sym("sbj_unique")) # note that by default the standard error will be HC2, you can change it by specifying "se_type = " as an argument in the quick_lm() function. It will be passed to the lm_robust() function
results4$table <- results4$table[order(results4$table$outcome),]
dfLab4 <- results4$table
dfLab4$dataset <- factor(dfLab4$dataset, 
                         levels = rev(c("Uganda June 2017", "Uganda January 2017", "Ghana July 2016", 
                                        "Pooled"))) 
dfLab4$outcome <- factor(dfLab4$outcome, 
                         levels = rev(depVars))
het4 <- dfLab4[, c(1,4,5,7)]
het4 <- het4 %>% 
  mutate_if(is.numeric, round, digits=3)

################## Low Ed Pooled

results5 <- quick_lm(dep.vars = depVars, 
                     dep.names = depNames,
                     ind.vars = c(controlsedu, feVars, treatVar), 
                     data = dfList5, 
                     keep.vars.tab = treatVar,
                     keep.vars.plot = treatVar,
                     inc.plot = F, 
                     data.names = names(dfList5),
                     subset.by = "dataset", 
                     stand.vars = depVars, 
                     se_type = "CR2",
                     cluster = sym("sbj_unique")) # note that by default the standard error will be HC2, you can change it by specifying "se_type = " as an argument in the quick_lm() function. It will be passed to the lm_robust() function
results5$table <- results5$table[order(results5$table$outcome),]
dfLab5 <- results5$table
dfLab5$dataset <- factor(dfLab5$dataset, 
                         levels = rev(c("Uganda June 2017", "Uganda January 2017", "Ghana July 2016", 
                                        "Pooled"))) 
dfLab5$outcome <- factor(dfLab5$outcome, 
                         levels = rev(depVars))
het5 <- dfLab5[, c(1,4,5,7)]
het5 <- het5 %>% 
  mutate_if(is.numeric, round, digits=3)

############## Combining heterogeneity test variables into a combined format

tabc4 <- cbind(het1, het2, het3, het4, het5)
tabc4 <- tabc4[, c(1:4, 6:8, 10:12, 14:16, 18:20)]
dt <- tabc4[,c(1:4, 5:7, 8:10, 11:13, 14:16)]

### Note - Replace Uganda June 2017 values for Age 50+ with NA
### Estimates matrix is rank deficient - Not enough observations

kable(dt, format = "html", booktabs = T, caption = "Table C15") %>%
  kable_styling(latex_options = c("striped", "hold_position"),
                full_width = F) %>%
  add_header_above(c(" ", "Age 20-35" = 3, "Age 35-50" = 3, "Age 50+" = 3, "High Ed" = 3, "Low Ed" = 3))
