gc(); rm(list = ls()); set.seed(12345)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) # Note: if you are not using R Studio this command will not work, set WD to source file location manually
require(magrittr)
require(plyr)
require(dplyr)
require(stringr)
require(data.table)
require(kableExtra)
require(stargazer)
source("../../function.R") 
load("../../data/final/lab_data_final.RData") 


############ Create heterogeneity test variables (Sex, Services High/Low, Poverty High/Low)

for(i in 1:length(dfList)){
  dfList[[i]] <- mutate(dfList[[i]], male = ifelse((dfList[[i]]$female==0),1,0))
}

quantile(dfList$`Ghana July 2016`$services_avg, na.rm = TRUE)

dfList$`Ghana July 2016` <- mutate(dfList$`Ghana July 2016`, services_high = ifelse((dfList$`Ghana July 2016`$services_avg>4.714286),1,0))
dfList$`Ghana July 2016` <- mutate(dfList$`Ghana July 2016`, services_low = ifelse((dfList$`Ghana July 2016`$services_avg<=4.714286),1,0))

quantile(dfList$`Uganda January 2017`$services_avg, na.rm = TRUE)

dfList$`Uganda January 2017` <- mutate(dfList$`Uganda January 2017`, services_high = ifelse((dfList$`Uganda January 2017`$services_avg>4.571429),1,0))
dfList$`Uganda January 2017` <- mutate(dfList$`Uganda January 2017`, services_low = ifelse((dfList$`Uganda January 2017`$services_avg<=4.571429),1,0))


quantile(dfList$`Uganda June 2017`$services_avg, na.rm = TRUE)

dfList$`Uganda June 2017` <- mutate(dfList$`Uganda June 2017`, services_high = ifelse((dfList$`Uganda June 2017`$services_avg>4.25),1,0))
dfList$`Uganda June 2017` <- mutate(dfList$`Uganda June 2017`, services_low = ifelse((dfList$`Uganda June 2017`$services_avg<=4.25),1,0))


quantile(dfList$Pooled$services_avg, na.rm = TRUE)
dfList$Pooled <- mutate(dfList$Pooled, services_high = ifelse((dfList$Pooled$services_avg>4.571429),1,0))
dfList$Pooled <- mutate(dfList$Pooled, services_low = ifelse((dfList$Pooled$services_avg<=4.571429),1,0))



quantile(dfList$`Ghana July 2016`$poverty_avg, na.rm = TRUE)

dfList$`Ghana July 2016` <- mutate(dfList$`Ghana July 2016`, poverty_high = ifelse((dfList$`Ghana July 2016`$poverty_avg>2),1,0))
dfList$`Ghana July 2016` <- mutate(dfList$`Ghana July 2016`, poverty_low = ifelse((dfList$`Ghana July 2016`$poverty_avg<=2),1,0))

quantile(dfList$`Uganda January 2017`$poverty_avg, na.rm = TRUE)

dfList$`Uganda January 2017` <- mutate(dfList$`Uganda January 2017`, poverty_high = ifelse((dfList$`Uganda January 2017`$poverty_avg>3),1,0))
dfList$`Uganda January 2017` <- mutate(dfList$`Uganda January 2017`, poverty_low = ifelse((dfList$`Uganda January 2017`$poverty_avg<=3),1,0))


quantile(dfList$`Uganda June 2017`$poverty_avg, na.rm = TRUE)

dfList$`Uganda June 2017` <- mutate(dfList$`Uganda June 2017`, poverty_high = ifelse((dfList$`Uganda June 2017`$poverty_avg>2.5),1,0))
dfList$`Uganda June 2017` <- mutate(dfList$`Uganda June 2017`, poverty_low = ifelse((dfList$`Uganda June 2017`$poverty_avg<=2.5),1,0))


quantile(dfList$Pooled$poverty_avg, na.rm = TRUE)
dfList$Pooled <- mutate(dfList$Pooled, poverty_high = ifelse((dfList$Pooled$poverty_avg>2.5),1,0))
dfList$Pooled <- mutate(dfList$Pooled, poverty_low = ifelse((dfList$Pooled$poverty_avg<=2.5),1,0))





dfList <- lapply(dfList, function(x) x[(names(x) %in% c(clusterVars, depVars, treatVar, controlVars, feVars, "male",
                                                        "services_high", "services_low", "poverty_high", "poverty_low"))])


## Drop enumerators with less than 2 observations (need this for the lm_robust function to work)

dfList1 <- lapply(dfList, subset, female==1)
for(i in 1:length(dfList1)){
  
  numSbj <- tapply(dfList1[[i]]$enum_id, dfList1[[i]]$enum_id, length)
enumKeep <- names(numSbj[numSbj >= 2])
dfList1[[i]] <- dfList1[[i]][dfList1[[i]]$enum_id %in% enumKeep, ]
}

dfList2 <- lapply(dfList, subset, male==1)
for(i in 1:length(dfList2)){
  
  numSbj <- tapply(dfList2[[i]]$enum_id, dfList2[[i]]$enum_id, length)
  enumKeep <- names(numSbj[numSbj >= 2])
  dfList2[[i]] <- dfList2[[i]][dfList2[[i]]$enum_id %in% enumKeep, ]
}

dfList3 <- lapply(dfList, subset, services_high==1)
for(i in 1:length(dfList3)){
  
  numSbj <- tapply(dfList3[[i]]$enum_id, dfList3[[i]]$enum_id, length)
  enumKeep <- names(numSbj[numSbj >= 2])
  dfList3[[i]] <- dfList3[[i]][dfList3[[i]]$enum_id %in% enumKeep, ]
}

dfList4 <- lapply(dfList, subset, services_low==1)
for(i in 1:length(dfList4)){
  
  numSbj <- tapply(dfList4[[i]]$enum_id, dfList4[[i]]$enum_id, length)
  enumKeep <- names(numSbj[numSbj >= 2])
  dfList4[[i]] <- dfList4[[i]][dfList4[[i]]$enum_id %in% enumKeep, ]
}

dfList5 <- lapply(dfList, subset, poverty_high==1)
for(i in 1:length(dfList5)){
  
  numSbj <- tapply(dfList5[[i]]$enum_id, dfList5[[i]]$enum_id, length)
  enumKeep <- names(numSbj[numSbj >= 2])
  dfList5[[i]] <- dfList5[[i]][dfList5[[i]]$enum_id %in% enumKeep, ]
}

dfList6 <- lapply(dfList, subset, poverty_low==1)
for(i in 1:length(dfList6)){
  
  numSbj <- tapply(dfList6[[i]]$enum_id, dfList6[[i]]$enum_id, length)
  enumKeep <- names(numSbj[numSbj >= 2])
  dfList6[[i]] <- dfList6[[i]][dfList6[[i]]$enum_id %in% enumKeep, ]
}

######################## Create appropriate control variables ##################

controlsex <- controlVars[c(1,2,4,5)]
controlserv <- controlVars[c(1:3,5)]
controlpov <- controlVars[c(1:4)]

######################### ESTIMATE #############################################

######### Female 
results1 <- quick_lm(dep.vars = depVars, 
                    dep.names = depNames,
                    ind.vars = c(controlsex, feVars, treatVar), 
                    data = dfList1, 
                    keep.vars.tab = treatVar,
                    keep.vars.plot = treatVar,
                    inc.plot = F, 
                    data.names = names(dfList1),
                    subset.by = "dataset", 
                    stand.vars = depVars, 
                    se_type = "CR2",
                    cluster = sym("sbj_unique")) # note that by default the standard error will be HC2, you can change it by specifying "se_type = " as an argument in the quick_lm() function. It will be passed to the lm_robust() function




results1$table <- results1$table[order(results1$table$outcome),]
dfLab1 <- results1$table
dfLab1$dataset <- factor(dfLab1$dataset, 
                        levels = rev(c("Uganda June 2017", "Uganda January 2017", "Ghana July 2016", 
                                       "Pooled"))) 
dfLab1$outcome <- factor(dfLab1$outcome, 
                        levels = rev(depVars))
het1 <- dfLab1[, c(1,4,5,7)]
het1 <- het1 %>% 
  mutate_if(is.numeric, round, digits=3)

######### Male

results2 <- quick_lm(dep.vars = depVars, 
                     dep.names = depNames,
                     ind.vars = c(controlsex, feVars, treatVar), 
                     data = dfList2, 
                     keep.vars.tab = treatVar,
                     keep.vars.plot = treatVar,
                     inc.plot = F, 
                     data.names = names(dfList2),
                     subset.by = "dataset", 
                     stand.vars = depVars, 
                     se_type = "CR2",
                     cluster = sym("sbj_unique")) # note that by default the standard error will be HC2, you can change it by specifying "se_type = " as an argument in the quick_lm() function. It will be passed to the lm_robust() function
results2$table <- results2$table[order(results2$table$outcome),]
dfLab2 <- results2$table
dfLab2$dataset <- factor(dfLab2$dataset, 
                         levels = rev(c("Uganda June 2017", "Uganda January 2017", "Ghana July 2016", 
                                        "Pooled"))) 
dfLab2$outcome <- factor(dfLab2$outcome, 
                         levels = rev(depVars))
het2 <- dfLab2[, c(1,4,5,7)]
het2 <- het2 %>% 
  mutate_if(is.numeric, round, digits=3)

############# Services High


results3 <- quick_lm(dep.vars = depVars, 
                     dep.names = depNames,
                     ind.vars = c(controlserv, feVars, treatVar), 
                     data = dfList3, 
                     keep.vars.tab = treatVar,
                     keep.vars.plot = treatVar,
                     inc.plot = F, 
                     data.names = names(dfList3),
                     subset.by = "dataset", 
                     stand.vars = depVars, 
                     se_type = "CR2",
                     cluster = sym("sbj_unique")) # note that by default the standard error will be HC2, you can change it by specifying "se_type = " as an argument in the quick_lm() function. It will be passed to the lm_robust() function

results3$table <- results3$table[order(results3$table$outcome),]
dfLab3 <- results3$table
dfLab3$dataset <- factor(dfLab3$dataset, 
                         levels = rev(c("Uganda June 2017", "Uganda January 2017", "Ghana July 2016", 
                                        "Pooled"))) 
dfLab3$outcome <- factor(dfLab3$outcome, 
                         levels = rev(depVars))
het3 <- dfLab3[, c(1,4,5,7)]
het3 <- het3 %>% 
  mutate_if(is.numeric, round, digits=3)

################ Services Low

results4 <- quick_lm(dep.vars = depVars, 
                     dep.names = depNames,
                     ind.vars = c(controlserv, feVars, treatVar), 
                     data = dfList4, 
                     keep.vars.tab = treatVar,
                     keep.vars.plot = treatVar,
                     inc.plot = F, 
                     data.names = names(dfList4),
                     subset.by = "dataset", 
                     stand.vars = depVars, 
                     se_type = "CR2",
                     cluster = sym("sbj_unique")) # note that by default the standard error will be HC2, you can change it by specifying "se_type = " as an argument in the quick_lm() function. It will be passed to the lm_robust() function
results4$table <- results4$table[order(results4$table$outcome),]
dfLab4 <- results4$table
dfLab4$dataset <- factor(dfLab4$dataset, 
                         levels = rev(c("Uganda June 2017", "Uganda January 2017", "Ghana July 2016", 
                                        "Pooled"))) 
dfLab4$outcome <- factor(dfLab4$outcome, 
                         levels = rev(depVars))
het4 <- dfLab4[, c(1,4,5,7)]
het4 <- het4 %>% 
  mutate_if(is.numeric, round, digits=3)

################## Poverty High

results5 <- quick_lm(dep.vars = depVars, 
                     dep.names = depNames,
                     ind.vars = c(controlpov, feVars, treatVar), 
                     data = dfList5, 
                     keep.vars.tab = treatVar,
                     keep.vars.plot = treatVar,
                     inc.plot = F, 
                     data.names = names(dfList5),
                     subset.by = "dataset", 
                     stand.vars = depVars, 
                     se_type = "CR2",
                     cluster = sym("sbj_unique")) # note that by default the standard error will be HC2, you can change it by specifying "se_type = " as an argument in the quick_lm() function. It will be passed to the lm_robust() function
results5$table <- results5$table[order(results5$table$outcome),]
dfLab5 <- results5$table
dfLab5$dataset <- factor(dfLab5$dataset, 
                         levels = rev(c("Uganda June 2017", "Uganda January 2017", "Ghana July 2016", 
                                        "Pooled"))) 
dfLab5$outcome <- factor(dfLab5$outcome, 
                         levels = rev(depVars))
het5 <- dfLab5[, c(1,4,5,7)]
het5 <- het5 %>% 
  mutate_if(is.numeric, round, digits=3)

############ Poverty Low

results6 <- quick_lm(dep.vars = depVars, 
                     dep.names = depNames,
                     ind.vars = c(controlpov, feVars, treatVar), 
                     data = dfList6, 
                     keep.vars.tab = treatVar,
                     keep.vars.plot = treatVar,
                     inc.plot = F, 
                     data.names = names(dfList6),
                     subset.by = "dataset", 
                     stand.vars = depVars, 
                     se_type = "CR2",
                     cluster = sym("sbj_unique")) # note that by default the standard error will be HC2, you can change it by specifying "se_type = " as an argument in the quick_lm() function. It will be passed to the lm_robust() function

results6$table <- results6$table[order(results6$table$outcome),]
dfLab6 <- results6$table
dfLab6$dataset <- factor(dfLab6$dataset, 
                         levels = rev(c("Uganda June 2017", "Uganda January 2017", "Ghana July 2016", 
                                        "Pooled"))) 
dfLab6$outcome <- factor(dfLab6$outcome, 
                         levels = rev(depVars))
het6 <- dfLab6[, c(1,4,5,7)]
het6 <- het6 %>% 
  mutate_if(is.numeric, round, digits=3)

############## Combining heterogeneity test variables into a combined format

tabc4 <- cbind(het1, het2, het3, het4, het5, het6)
tabc4 <- tabc4[, c(1:4, 6:8, 10:12, 14:16, 18:20, 22:24)]
dt <- tabc4[,c(1:4, 5:7, 8:10, 11:13, 14:16, 17:19)]

kable(dt, format = "latex", booktabs = T, caption = "Table C17") %>%
  kable_styling(latex_options = c("striped", "hold_position"),
                full_width = F) %>%
  add_header_above(c(" ", "Female" = 3, "Male" = 3, "Services High" = 3, "Services Low" = 3,
                     "Poverty High" = 3, "Poverty Low" = 3))
