gc(); rm(list = ls()); set.seed(12345)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) # Note: if you are not using R Studio this command will not work, set WD to source file location manually
require(magrittr)
require(plyr)
require(dplyr)
require(stringr)
require(data.table)
require(patchwork)
require(ggthemes)
require(kableExtra)
source("../../function.R")

load("../../data/final/field_data_final.RData")

############ Create heterogeneity test variables (Age, Education)

ugField <- mutate(ugField, age_20_35 = ifelse((ugField$ptc_age>20 & ugField$ptc_age<35),1,0))
ugField <- mutate(ugField, age_35_50 = ifelse((ugField$ptc_age>=35 & ugField$ptc_age<50),1,0))
ugField <- mutate(ugField, age_50p = ifelse((ugField$ptc_age>=50),1,0))

quantile(ugField$ptc_edu, na.rm = TRUE)
ugField <- mutate(ugField, edu_high = ifelse((ugField$ptc_edu > 11),1,0))
ugField <- mutate(ugField, edu_low = ifelse((ugField$ptc_edu <= 11),1,0))

incTreat <- c("Aid Info", "Oil Info")
dfUsing <- ugField[ugField$treat_factor %in% incTreat, ]

dfUsing$aid_info <- ifelse(dfUsing$treat_factor == "Aid Info", 1, 0)
treatVar <- c("aid_info")


## Drop enumerators with less than 2 observations
## This is the minimum threshold needed to allow estimation using the lm_robust() function

dfUsing1 <- subset(dfUsing, age_20_35==1)

numSbj <- tapply(dfUsing1$enum_enumerator, dfUsing1$enum_enumerator, length)
enumKeep <- names(numSbj[numSbj >= 2])
dfUsing1 <- dfUsing1[dfUsing1$enum_enumerator %in% enumKeep, ]


dfUsing2 <- subset(dfUsing, age_35_50==1)

  numSbj <- tapply(dfUsing2$enum_enumerator, dfUsing2$enum_enumerator, length)
  enumKeep <- names(numSbj[numSbj >= 2])
  dfUsing2 <- dfUsing2[dfUsing2$enum_enumerator %in% enumKeep, ]


dfUsing3 <- subset(dfUsing, age_50p==1)

  numSbj <- tapply(dfUsing3$enum_enumerator, dfUsing3$enum_enumerator, length)
  enumKeep <- names(numSbj[numSbj >= 2])
  dfUsing3 <- dfUsing3[dfUsing3$enum_enumerator %in% enumKeep, ]


dfUsing4 <- subset(dfUsing, edu_high==1)

  numSbj <- tapply(dfUsing4$enum_enumerator, dfUsing4$enum_enumerator, length)
  enumKeep <- names(numSbj[numSbj >= 2])
  dfUsing4 <- dfUsing4[dfUsing4$enum_enumerator %in% enumKeep, ]


dfUsing5 <- subset(dfUsing, edu_low==1)

  numSbj <- tapply(dfUsing5$enum_enumerator, dfUsing5$enum_enumerator, length)
  enumKeep <- names(numSbj[numSbj >= 2])
  dfUsing5 <- dfUsing5[dfUsing5$enum_enumerator %in% enumKeep, ]



######################## Create appropriate control variables ##################

controledu <- controlVars[c(2,3,5)]
controlage <- controlVars[c(1,3,5)]

######################### ESTIMATE #############################################

######### Age 20-35
results1 <- quick_lm(data = dfUsing1,
                     dep.vars = depVars,
                    ind.vars = c(treatVar, controlage), 
                    keep.vars.tab = treatVar, 
                    subset.by = "dataset", 
                    dep.names = depNames)
require('texreg')
dfRes1 <- results1$table
dfRes1$outcome <- factor(dfRes1$outcome, 
                        levels = rev(depNames))
roundVars <- c('estimate', 'std.error', 'p.value')
dfRes1[,roundVars] <- round(dfRes1[, roundVars], digits = 3)
colsInc <- c('outcome', 'estimate', 'std.error', 'p.value')
kable(dfRes1[, colsInc], digits = 3, "rst")
het1 <- dfRes1[, c(2,4,5,7)]

######### Age 35-50
results2 <- quick_lm(data = dfUsing2,
                     dep.vars = depVars,
                     ind.vars = c(treatVar, controlage), 
                     keep.vars.tab = treatVar, 
                     subset.by = "dataset", 
                     dep.names = depNames)

require('texreg')
dfRes2 <- results2$table
dfRes2$outcome <- factor(dfRes2$outcome, 
                         levels = rev(depNames))
roundVars <- c('estimate', 'std.error', 'p.value')
dfRes2[,roundVars] <- round(dfRes2[, roundVars], digits = 3)
colsInc <- c('outcome', 'estimate', 'std.error', 'p.value')
kable(dfRes2[, colsInc], digits = 3, "rst")
het2 <- dfRes2[, c(2,4,5,7)]

######### Age 50 plus
results3 <- quick_lm(data = dfUsing3,
                     dep.vars = depVars,
                     ind.vars = c(treatVar, controlage), 
                     keep.vars.tab = treatVar, 
                     subset.by = "dataset", 
                     dep.names = depNames)


require('texreg')
dfRes3 <- results3$table
dfRes3$outcome <- factor(dfRes3$outcome, 
                         levels = rev(depNames))
roundVars <- c('estimate', 'std.error', 'p.value')
dfRes3[,roundVars] <- round(dfRes3[, roundVars], digits = 3)
colsInc <- c('outcome', 'estimate', 'std.error', 'p.value')
kable(dfRes3[, colsInc], digits = 3, "rst")
het3 <- dfRes3[, c(2,4,5,7)]

######### Edu High
results4 <- quick_lm(data = dfUsing4,
                     dep.vars = depVars,
                     ind.vars = c(treatVar, controledu), 
                     keep.vars.tab = treatVar, 
                     subset.by = "dataset", 
                     dep.names = depNames)


require('texreg')
dfRes4 <- results4$table
dfRes4$outcome <- factor(dfRes4$outcome, 
                         levels = rev(depNames))
roundVars <- c('estimate', 'std.error', 'p.value')
dfRes4[,roundVars] <- round(dfRes4[, roundVars], digits = 3)
colsInc <- c('outcome', 'estimate', 'std.error', 'p.value')
kable(dfRes4[, colsInc], digits = 3, "rst")
het4 <- dfRes4[, c(2,4,5,7)]

######### Edu Low
results5 <- quick_lm(data = dfUsing5,
                     dep.vars = depVars,
                     ind.vars = c(treatVar, controledu), 
                     keep.vars.tab = treatVar, 
                     subset.by = "dataset", 
                     dep.names = depNames)


require('texreg')
dfRes5 <- results5$table
dfRes5$outcome <- factor(dfRes5$outcome, 
                         levels = rev(depNames))
roundVars <- c('estimate', 'std.error', 'p.value')
dfRes5[,roundVars] <- round(dfRes5[, roundVars], digits = 3)
colsInc <- c('outcome', 'estimate', 'std.error', 'p.value')

kable(dfRes5[, colsInc], digits = 3, "rst")

het5 <- dfRes5[, c(2,4,5,7)]



############## Combining heterogeneity test variables into a combined format

tabc4 <- cbind(het1, het2, het3, het4, het5)
tabc4 <- tabc4[, c(1:4, 6:8, 10:12, 14:16, 18:20)]
dt <- tabc4[,c(1:4, 5:7, 8:10, 11:13, 14:16)]

kable(dt, format = "latex", booktabs = T, caption = "Table C18") %>%
  kable_styling(latex_options = c("striped", "hold_position"),
                full_width = F) %>%
  add_header_above(c(" ", "Age 20-35" = 3, "Age 35-50" = 3, "Age 50+" = 3, "High Education" = 3,
                     "Low Education" = 3))
