gc(); rm(list = ls()); set.seed(12345)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) # Note: if you are not using R Studio this command will not work, set WD to source file location manually
require(magrittr)
require(plyr)
require(dplyr)
require(stringr)
require(data.table)
require(patchwork)
require(ggthemes)
require(kableExtra)
source("../../function.R")

load("../../data/final/field_data_final.RData")

############ Create heterogeneity test variables (Sex, Services)

ugField <- mutate(ugField, male = ifelse((ugField$ptc_female==0),1,0))


quantile(ugField$services_avg, na.rm = TRUE)
ugField <- mutate(ugField, serv_high = ifelse((ugField$services_avg > 3.4),1,0))
ugField <- mutate(ugField, serv_low = ifelse((ugField$services_avg <= 3.4),1,0))

incTreat <- c("Aid Info", "Oil Info")
dfUsing <- ugField[ugField$treat_factor %in% incTreat, ]

dfUsing$aid_info <- ifelse(dfUsing$treat_factor == "Aid Info", 1, 0)
treatVar <- c("aid_info")


## Drop enumerators with less than 2 observations 
## This is the minimum threshold needed to allow estimation using the lm_robust() function

dfUsing1 <- subset(dfUsing, ptc_female==1)

numSbj <- tapply(dfUsing1$enum_enumerator, dfUsing1$enum_enumerator, length)
enumKeep <- names(numSbj[numSbj >= 2])
dfUsing1 <- dfUsing1[dfUsing1$enum_enumerator %in% enumKeep, ]


dfUsing2 <- subset(dfUsing, male==1)

  numSbj <- tapply(dfUsing2$enum_enumerator, dfUsing2$enum_enumerator, length)
  enumKeep <- names(numSbj[numSbj >= 2])
  dfUsing2 <- dfUsing2[dfUsing2$enum_enumerator %in% enumKeep, ]


dfUsing3 <- subset(dfUsing, serv_high==1)

  numSbj <- tapply(dfUsing3$enum_enumerator, dfUsing3$enum_enumerator, length)
  enumKeep <- names(numSbj[numSbj >= 2])
  dfUsing3 <- dfUsing3[dfUsing3$enum_enumerator %in% enumKeep, ]


dfUsing4 <- subset(dfUsing, serv_low==1)

  numSbj <- tapply(dfUsing4$enum_enumerator, dfUsing4$enum_enumerator, length)
  enumKeep <- names(numSbj[numSbj >= 2])
  dfUsing4 <- dfUsing4[dfUsing4$enum_enumerator %in% enumKeep, ]




######################## Create appropriate control variables ##################

controlsex <- controlVars[c(1,2,5)]

######################### ESTIMATE #############################################

######### Female
results1 <- quick_lm(data = dfUsing1,
                     dep.vars = depVars,
                    ind.vars = c(treatVar, controlsex), 
                    keep.vars.tab = treatVar, 
                    subset.by = "dataset", 
                    dep.names = depNames)
require('texreg')
dfRes1 <- results1$table
dfRes1$outcome <- factor(dfRes1$outcome, 
                        levels = rev(depNames))
roundVars <- c('estimate', 'std.error', 'p.value')
dfRes1[,roundVars] <- round(dfRes1[, roundVars], digits = 3)
colsInc <- c('outcome', 'estimate', 'std.error', 'p.value')
kable(dfRes1[, colsInc], digits = 3, "rst")
het1 <- dfRes1[, c(2,4,5,7)]

######### Male
results2 <- quick_lm(data = dfUsing2,
                     dep.vars = depVars,
                     ind.vars = c(treatVar, controlsex), 
                     keep.vars.tab = treatVar, 
                     subset.by = "dataset", 
                     dep.names = depNames)
dfRes2 <- results2$table
dfRes2$outcome <- factor(dfRes2$outcome, 
                         levels = rev(depNames))
roundVars <- c('estimate', 'std.error', 'p.value')
dfRes2[,roundVars] <- round(dfRes2[, roundVars], digits = 3)
colsInc <- c('outcome', 'estimate', 'std.error', 'p.value')
kable(dfRes2[, colsInc], digits = 3, "rst")
het2 <- dfRes2[, c(2,4,5,7)]

######### Services High
results3 <- quick_lm(data = dfUsing3,
                     dep.vars = depVars,
                     ind.vars = c(treatVar, controlVars), 
                     keep.vars.tab = treatVar, 
                     subset.by = "dataset", 
                     dep.names = depNames)
dfRes3 <- results3$table
dfRes3$outcome <- factor(dfRes3$outcome, 
                         levels = rev(depNames))
roundVars <- c('estimate', 'std.error', 'p.value')
dfRes3[,roundVars] <- round(dfRes3[, roundVars], digits = 3)
colsInc <- c('outcome', 'estimate', 'std.error', 'p.value')
kable(dfRes3[, colsInc], digits = 3, "rst")
het3 <- dfRes3[, c(2,4,5,7)]

######### Services Low

results4 <- quick_lm(data = dfUsing4,
                     dep.vars = depVars,
                     ind.vars = c(treatVar, controlVars), 
                     keep.vars.tab = treatVar, 
                     subset.by = "dataset", 
                     dep.names = depNames)
dfRes4 <- results4$table
dfRes4$outcome <- factor(dfRes4$outcome, 
                         levels = rev(depNames))
roundVars <- c('estimate', 'std.error', 'p.value')
dfRes4[,roundVars] <- round(dfRes4[, roundVars], digits = 3)
colsInc <- c('outcome', 'estimate', 'std.error', 'p.value')
kable(dfRes4[, colsInc], digits = 3, "rst")
het4 <- dfRes4[, c(2,4,5,7)]

############## Combining heterogeneity test variables into a combined format

tabc4 <- cbind(het1, het2, het3, het4)
tabc4 <- tabc4[, c(1:4, 6:8, 10:12, 14:16)]
dt <- tabc4[,c(1:4, 5:7, 8:10, 11:13)]

kable(dt, format = "latex", booktabs = T, caption = "Table C19") %>%
  kable_styling(latex_options = c("striped", "hold_position"),
                full_width = F) %>%
  add_header_above(c(" ", "Female" = 3, "Male" = 3, "Service High" = 3, "Services Low" = 3))
