  gc(); rm(list = ls()); set.seed(12345)
  setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) 
  # Note: if you are not using R Studio this command will not work, 
  # set WD to source file location manually
  require(magrittr)
  require(plyr)
  require(dplyr)
  require(stringr)
  require(data.table)
  require(kableExtra)
  source("../../function.R")
  load("../../data/final/field_data_final.RData") 
  
  
  ############# Aid Treatment, No Info Control  ##################################
  
  df_field_aid_noinfo <- ugField[ugField$treat_factor %in% c("Pure Control", 
                                                             "Aid Info"), ]
  
  treat_var <- c("aid_info")
  results_aid_noinfo <- quick_lm(data = df_field_aid_noinfo,
                      dep.vars = depVars,
                      dep.names = depNames,
                      ind.vars = c(treat_var, 
                                   controlVars), 
                      keep.vars.tab = treat_var) 
  
  require('texreg')
  df_table_aid_noinfo <- results_aid_noinfo$table
  round_vars <- c('estimate', 
                 'std.error', 
                 'p.value')
  
  df_table_aid_noinfo[, round_vars] <- round(df_table_aid_noinfo[, round_vars], 
                                            digits = 3)
  cols_inc <- c('outcome', 
               'estimate', 
               'std.error', 
               'p.value')
  
  kable(df_table_aid_noinfo[, cols_inc], 
        digits = 3, 
        "rst")
  
  ############## Aid Treatment, Oil Control ######################################
  
  df_field_aid_oil <- ugField[ugField$treat_factor %in% c("Aid Info", "Oil Info"), ]
  enum_obs <- tapply(df_field_aid_oil$enum_enumerator, 
                     df_field_aid_oil$enum_enumerator, 
                     length)
  # Drop any data by enumerators with not enough observations
  rm_enum <- names(enum_obs[enum_obs <= 2])
  df_field_aid_oil_clean <- 
    df_field_aid_oil[!df_field_aid_oil$enum_enumerator %in% rm_enum, ]
  
  
  treat_var <- c("aid_info")
  results_aid_oil <- quick_lm(data = df_field_aid_oil_clean,
                      dep.vars = depVars,
                      dep.names = depNames,
                      ind.vars = c(treat_var, controlVars), 
                      keep.vars.tab = treat_var) 
  
  
  df_table_aid_oil <- results_aid_oil$table
  round_vars <- c('estimate', 
                 'std.error', 
                 'p.value')
  df_table_aid_oil[, round_vars] <- round(df_table_aid_oil[, round_vars], 
                                         digits = 3)
  cols_inc <- c('outcome', 
                'estimate', 
                'std.error', 
                'p.value')
  kable(df_table_aid_oil[, cols_inc], 
        digits = 3, 
        "rst")
  
  
  ########### Oil Treatment, No Info Control  ####################################
  
  df_field_oil_noinfo <- ugField[ugField$treat_factor %in% c("Pure Control", 
                                                             "Oil Info"),]
  enum_obs <- tapply(df_field_oil_noinfo$enum_enumerator, 
                     df_field_oil_noinfo$enum_enumerator, 
                     length)
  # Drop any data by enumerators with not enough observations
  rm_enum <- names(enum_obs[enum_obs <= 2])
  df_field_oil_noinfo_clean <- 
    df_field_oil_noinfo[!df_field_oil_noinfo$enum_enumerator %in% rm_enum, ]
  
  treat_var = "oil_info"
  
  results_oil_noinfo <- quick_lm(data = df_field_oil_noinfo_clean,
                       dep.vars = depVars,
                       dep.names = depNames,
                       ind.vars = c(treat_var, controlVars), 
                       keep.vars.tab = treat_var)
  
  
  df_table_oil_noinfo <- results_oil_noinfo$table
  round_vars <- c('estimate', 
                 'std.error', 
                 'p.value')
  df_table_oil_noinfo[, round_vars] <- round(df_table_oil_noinfo[, round_vars], 
                                            digits = 3)
  cols_inc <- c('outcome', 
                'estimate', 
                'std.error', 
                'p.value')
  
  kable(df_table_oil_noinfo[, cols_inc], 
        digits = 3, 
        "rst")




################################################################################
##################### Panel B ##################################################
################################################################################

### Aid Treat - No Info Control

vars_use <- c("om_gov_budget_aid", 
              "om_gov_budget_oil")

df_field_infoupdate_aid_noinfo <- ugField[ugField$treat_factor %in% c("Pure Control", 
                                                                      "Aid Info"),]
enum_obs <- tapply(df_field_infoupdate_aid_noinfo$enum_enumerator, 
                   df_field_infoupdate_aid_noinfo$enum_enumerator, 
                   length)
# Drop any data by enumerators with not enough observations
rm_enum <- names(enum_obs[enum_obs <= 2])
df_field_infoupdate_aid_noinfo_clean <- 
  df_field_infoupdate_aid_noinfo[!df_field_infoupdate_aid_noinfo$enum_enumerator %in% rm_enum, ]

treat_var = "aid_info"


results_infoupdate_aid_noinfo <- quick_lm(data = df_field_infoupdate_aid_noinfo_clean, 
                                          dep.vars = vars_use, 
                                          ind.vars = c(treat_var, 
                                                       controlVars), 
                                          keep.vars.tab = treat_var)

df_table_infoupdate_aid_noinfo <- results_infoupdate_aid_noinfo$table
round_vars <- c('estimate', 'std.error', 'p.value')
df_table_infoupdate_aid_noinfo[,round_vars] <- round(df_table_infoupdate_aid_noinfo[, round_vars], digits = 3)
cols_inc <- c('outcome', 'estimate', 'std.error', 'p.value')

kable(df_table_infoupdate_aid_noinfo[, cols_inc], 
      digits = 3, 
      "rst")

#Average Baseline Proportion Increase
###Aid Selected
results_infoupdate_aid_noinfo$table$estimate[results_infoupdate_aid_noinfo$table$outcome == "om_gov_budget_aid"]/
  mean(ugField$om_gov_budget_aid[ugField$treat_factor == "Pure Control"], 
       na.rm = TRUE)


############## Aid Treatment, Oil Control ######################################

df_field_infoupdate_aid_oil <- ugField[ugField$treat_factor %in% c("Oil Info", 
                                                                   "Aid Info"),]
enum_obs <- tapply(df_field_infoupdate_aid_oil$enum_enumerator, 
                   df_field_infoupdate_aid_oil$enum_enumerator, 
                   length)
# Drop any data by enumerators with not enough observations
rm_enum <- names(enum_obs[enum_obs <= 2])
df_field_infoupdate_aid_oil_clean <- 
  df_field_infoupdate_aid_oil[!df_field_infoupdate_aid_oil$enum_enumerator %in% rm_enum, ]

treat_var = "aid_info"


results_infoupdate_aid_oil <- quick_lm(data = df_field_infoupdate_aid_oil_clean,
                     dep.vars = vars_use,
                     ind.vars = c(treat_var, controlVars), 
                     keep.vars.tab = treat_var)

df_table_infoupdate_aid_oil <- results_infoupdate_aid_oil$table
round_vars <- c('estimate', 'std.error', 'p.value')
df_table_infoupdate_aid_oil[, round_vars] <- round(df_table_infoupdate_aid_oil[, round_vars], 
                                                   digits = 3)
cols_inc <- c('outcome', 
              'estimate', 
              'std.error', 
              'p.value')

kable(df_table_infoupdate_aid_oil[, cols_inc], 
      digits = 3, "rst")

########### Oil Treatment, No Info Control  ####################################

df_field_infoupdate_oil_noinfo <- 
  ugField[ugField$treat_factor %in% c("Pure Control", 
                                      "Oil Info"), ]
enum_obs <- tapply(df_field_infoupdate_oil_noinfo$enum_enumerator, 
                   df_field_infoupdate_oil_noinfo$enum_enumerator, 
                   length)
# Drop any data by enumerators with not enough observations
rm_enum <- names(enum_obs[enum_obs <= 2])
df_field_infoupdate_oil_noinfo_clean <- 
  df_field_infoupdate_oil_noinfo[!df_field_infoupdate_oil_noinfo$enum_enumerator %in% rm_enum, ]

treat_var = "oil_info"


results_infoupdate_aid_oil <- quick_lm(data = df_field_infoupdate_oil_noinfo_clean,
                     dep.vars = vars_use,
                     ind.vars = c(treat_var, controlVars), 
                     keep.vars.tab = treat_var)

df_table_infoupdate_oil_noinfo <- results_infoupdate_aid_oil$table
round_vars <- c('estimate', 
                'std.error', 
                'p.value')
df_table_infoupdate_oil_noinfo[, round_vars] <- round(df_table_infoupdate_oil_noinfo[, round_vars], 
                                                      digits = 3)

cols_inc <- c('outcome', 
              'estimate', 
              'std.error', 
              'p.value')


kable(df_table_infoupdate_oil_noinfo[, cols_inc], digits = 3, "rst")

#Average Baseline Proportion Increase

###oil Selected  

results_infoupdate_aid_oil$table$estimate[results_infoupdate_aid_oil$table$outcome == "om_gov_budget_oil"]/
  mean(ugField$om_gov_budget_oil[ugField$treat_factor == "Pure Control"], na.rm = T)





