gc(); rm(list = ls()); set.seed(12345)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) # Note: if you are not using R Studio this command will not work, set WD to source file location manually
require(magrittr)
require(plyr)
require(dplyr)
require(stringr)
require(data.table)
require(kableExtra)
source("../../function.R") 
load("../../data/final/surveyexp_data_final.RData")


############ Create heterogeneity test variables (Age)

for(i in 1:length(dfList)){
  dfList[[i]] <- mutate(dfList[[i]], non_ruling = ifelse((dfList[[i]]$gov_supp==0),1,0))
  dfList[[i]] <- mutate(dfList[[i]], non_oil = ifelse((dfList[[i]]$oil_region==0),1,0))
}


########### Subset to Pooled Data

dfList <- dfList$Pooled
dfList <- dfList[c(actionVars, depVars, treatVar, controlVars, feVars, "gov_supp", "non_ruling",
                   "oil_region", "non_oil")]

## Drop enumerators with less than 2 observations (need this for the lm_robust function to work)

dfList1 <- subset(dfList, gov_supp==1)
numSbj <- tapply(dfList1$enum_id, dfList1$enum_id, length)
enumKeep <- names(numSbj[numSbj >= 2])
dfList1 <- dfList1[dfList1$enum_id %in% enumKeep, ]

dfList2 <- subset(dfList, non_ruling==1)
numSbj <- tapply(dfList2$enum_id, dfList2$enum_id, length)
enumKeep <- names(numSbj[numSbj >= 2])
dfList2 <- dfList2[dfList2$enum_id %in% enumKeep, ]

dfList3 <- subset(dfList, oil_region==1)
numSbj <- tapply(dfList3$enum_id, dfList3$enum_id, length)
enumKeep <- names(numSbj[numSbj >= 2])
dfList3 <- dfList3[dfList3$enum_id %in% enumKeep, ]

dfList4 <- subset(dfList, non_oil==1)
numSbj <- tapply(dfList4$enum_id, dfList4$enum_id, length)
enumKeep <- names(numSbj[numSbj >= 2])
dfList4 <- dfList4[dfList4$enum_id %in% enumKeep, ]



######################### ESTIMATE #############################################

######### High Poverty Pooled
results1 <- quick_lm(dep.vars = actionVars, 
                    dep.names = actionNames,
                    ind.vars = c(controlVars, feVars, treatVar), 
                    data = dfList1, 
                    keep.vars.tab = treatVar,
                    keep.vars.plot = treatVar,
                    inc.plot = F, 
                    subset.by = "dataset", 
                    stand.vars = "non-binary") # note that by default the standard error will be HC2, you can change it by specifying "se_type = " as an argument in the quick_lm() function. It will be passed to the lm_robust() function

results1$table$dataset <- mapvalues(results1$table$dataset, 
                                   from = c("dataset1"), 
                                   to = c("Pooled"))
results1$table$family <- NA
results1$table$family[results1$table$outcome %in% c("Action Index (NMWI)",
                                                  "Create Agency",
                                                  "Willing to Send SMS",
                                                  "Sent SMS",
                                                  "Donated (Binary)",
                                                  "Taxes Willing to Commit (Binary)",
                                                  "Signed Petition (Any)",
                                                  "Pr(Contact Village Elder)",
                                                  "Pr(Contact Local Official)",
                                                  "Pr(Contact MP)")] <- "Action" # Create "family" variable to subset with later


results1$table <- results1$table[order(results1$table$outcome),]


#"Action" Family Dependent Variables

ExpInc <- c("Pooled")
dfAction1 <- results1$table[results1$table$family == "Action", ]
dfAction1$dataset <- factor(dfAction1$dataset, 
                           levels = rev(c("Pooled"))) 
dfAction1$outcome <- factor(dfAction1$outcome, 
                           levels = rev(c("Action Index (NMWI)",
                                          "Create Agency",
                                          "Willing to Send SMS",
                                          "Sent SMS",
                                          "Donated (Binary)",
                                          "Taxes Willing to Commit (Binary)",
                                          "Signed Petition (Any)",
                                          "Pr(Contact Village Elder)",
                                          "Pr(Contact Local Official)",
                                          "Pr(Contact MP)")))
(dfUse1 <- dfAction1 %>%
    filter(dfAction1$family == "Action"))
dfUse1 <- dfUse1[c(1,2,4,5,7)]
het1 <- dfAction1[, c(2,4,5,7)]
het1 <- het1 %>% 
  mutate_if(is.numeric, round, digits=3)

######### Low Poverty Pooled

results2 <- quick_lm(dep.vars = actionVars, 
                     dep.names = actionNames,
                     ind.vars = c(controlVars, feVars, treatVar), 
                     data = dfList2, 
                     keep.vars.tab = treatVar,
                     keep.vars.plot = treatVar,
                     inc.plot = F, 
                     subset.by = "dataset", 
                     stand.vars = "non-binary") # note that by default the standard error will be HC2, you can change it by specifying "se_type = " as an argument in the quick_lm() function. It will be passed to the lm_robust() function

results2$table$dataset <- mapvalues(results2$table$dataset, 
                                    from = c("dataset1"), 
                                    to = c("Pooled"))
results2$table$family <- NA
results2$table$family[results2$table$outcome %in% c("Action Index (NMWI)",
                                                    "Create Agency",
                                                    "Willing to Send SMS",
                                                    "Sent SMS",
                                                    "Donated (Binary)",
                                                    "Taxes Willing to Commit (Binary)",
                                                    "Signed Petition (Any)",
                                                    "Pr(Contact Village Elder)",
                                                    "Pr(Contact Local Official)",
                                                    "Pr(Contact MP)")] <- "Action" # Create "family" variable to subset with later


results2$table <- results2$table[order(results2$table$outcome),]

#"Action" Family Dependent Variables

ExpInc <- c("Pooled")
dfAction2 <- results2$table[results2$table$family == "Action", ]
dfAction2$dataset <- factor(dfAction2$dataset, 
                            levels = rev(c("Pooled"))) 
dfAction2$outcome <- factor(dfAction2$outcome, 
                            levels = rev(c("Action Index (NMWI)",
                                           "Create Agency",
                                           "Willing to Send SMS",
                                           "Sent SMS",
                                           "Donated (Binary)",
                                           "Taxes Willing to Commit (Binary)",
                                           "Signed Petition (Any)",
                                           "Pr(Contact Village Elder)",
                                           "Pr(Contact Local Official)",
                                           "Pr(Contact MP)")))
(dfUse2 <- dfAction2 %>%
    filter(dfAction2$family == "Action"))
dfUse2 <- dfUse2[c(1,2,4,5,7)]
het2 <- dfAction2[, c(2,4,5,7)]
het2 <- het2 %>% 
  mutate_if(is.numeric, round, digits=3)

############# Coethnic Pooled

results3 <- quick_lm(dep.vars = actionVars, 
                     dep.names = actionNames,
                     ind.vars = c(controlVars, feVars, treatVar), 
                     data = dfList3, 
                     keep.vars.tab = treatVar,
                     keep.vars.plot = treatVar,
                     inc.plot = F, 
                     subset.by = "dataset", 
                     stand.vars = "non-binary") # note that by default the standard error will be HC3, you can change it by specifying "se_type = " as an argument in the quick_lm() function. It will be passed to the lm_robust() function

results3$table$dataset <- mapvalues(results3$table$dataset, 
                                    from = c("dataset1"), 
                                    to = c("Pooled"))
results3$table$family <- NA
results3$table$family[results3$table$outcome %in% c("Action Index (NMWI)",
                                                    "Create Agency",
                                                    "Willing to Send SMS",
                                                    "Sent SMS",
                                                    "Donated (Binary)",
                                                    "Taxes Willing to Commit (Binary)",
                                                    "Signed Petition (Any)",
                                                    "Pr(Contact Village Elder)",
                                                    "Pr(Contact Local Official)",
                                                    "Pr(Contact MP)")] <- "Action" # Create "family" variable to subset with later


results3$table <- results3$table[order(results3$table$outcome),]


#"Action" Family Dependent Variables


ExpInc <- c("Pooled")
dfAction3 <- results3$table[results3$table$family == "Action", ]
dfAction3$dataset <- factor(dfAction3$dataset, 
                            levels = rev(c("Pooled"))) 
dfAction3$outcome <- factor(dfAction3$outcome, 
                            levels = rev(c("Action Index (NMWI)",
                                           "Create Agency",
                                           "Willing to Send SMS",
                                           "Sent SMS",
                                           "Donated (Binary)",
                                           "Taxes Willing to Commit (Binary)",
                                           "Signed Petition (Any)",
                                           "Pr(Contact Village Elder)",
                                           "Pr(Contact Local Official)",
                                           "Pr(Contact MP)")))
(dfUse3 <- dfAction3 %>%
    filter(dfAction3$family == "Action"))
dfUse3 <- dfUse3[c(1,2,4,5,7)]
het3 <- dfAction3[, c(2,4,5,7)]
het3 <- het3 %>% 
  mutate_if(is.numeric, round, digits=3)

################ Non Coethnic Pooled

results4 <- quick_lm(dep.vars = actionVars, 
                     dep.names = actionNames,
                     ind.vars = c(controlVars, feVars, treatVar), 
                     data = dfList4, 
                     keep.vars.tab = treatVar,
                     keep.vars.plot = treatVar,
                     inc.plot = F, 
                     subset.by = "dataset", 
                     stand.vars = "non-binary") # note that by default the standard error will be HC4, you can change it by specifying "se_type = " as an argument in the quick_lm() function. It will be passed to the lm_robust() function
results4$table$dataset <- mapvalues(results4$table$dataset, 
                                    from = c("dataset1"), 
                                    to = c("Pooled"))
results4$table$family <- NA
results4$table$family[results4$table$outcome %in% c("Action Index (NMWI)",
                                                    "Create Agency",
                                                    "Willing to Send SMS",
                                                    "Sent SMS",
                                                    "Donated (Binary)",
                                                    "Taxes Willing to Commit (Binary)",
                                                    "Signed Petition (Any)",
                                                    "Pr(Contact Village Elder)",
                                                    "Pr(Contact Local Official)",
                                                    "Pr(Contact MP)")] <- "Action" # Create "family" variable to subset with later


results4$table <- results4$table[order(results4$table$outcome),]

#"Action" Family Dependent Variables

ExpInc <- c("Pooled")
dfAction4 <- results4$table[results4$table$family == "Action", ]
dfAction4$dataset <- factor(dfAction4$dataset, 
                            levels = rev(c("Pooled"))) 
dfAction4$outcome <- factor(dfAction4$outcome, 
                            levels = rev(c("Action Index (NMWI)",
                                           "Create Agency",
                                           "Willing to Send SMS",
                                           "Sent SMS",
                                           "Donated (Binary)",
                                           "Taxes Willing to Commit (Binary)",
                                           "Signed Petition (Any)",
                                           "Pr(Contact Village Elder)",
                                           "Pr(Contact Local Official)",
                                           "Pr(Contact MP)")))
(dfUse4 <- dfAction4 %>%
    filter(dfAction4$family == "Action"))
dfUse4 <- dfUse4[c(1,2,4,5,7)]
het4 <- dfAction4[, c(2,4,5,7)]
het4 <- het4 %>% 
  mutate_if(is.numeric, round, digits=3)

############## Combining heterogeneity test variables into a combined format

tabc4 <- cbind(het1, het2, het3, het4)
tabc4 <- tabc4[, c(1:4, 6:8, 10:12, 14:16)]
dt <- tabc4[,c(1:4, 5:7, 8:10, 11:13)]
kable(dt, format = "latex", booktabs = T, caption = "Table C7") %>%
  kable_styling(latex_options = c("striped", "hold_position"),
                full_width = F) %>%
  add_header_above(c(" ", "Ruling Party" = 3, "Non-Ruling Party" = 3, "Oil Region" = 3, "Non-Oil Region" = 3))
