gc(); rm(list = ls()); set.seed(12345)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) # Note: if you are not using R Studio this command will not work, set WD to source file location manually
require(stargazer)
source("../../function.R") 
load("../../data/final/lab_data_final.RData")

dfUsing <- dfList$`Uganda June 2017`
balUse <- c("age", "edu", "pov_water", "pov_food", "vote", "female", "services_avg")
balNames <- c("Age", "Education", "How Often Gone Without Water", 
              "How Often Gone Without Food", 
              "Voted in Prior Election", "Female", "Quality of Public Goods")

treatVars <- "treatment"
balTab <- round(t(sapply(balUse, FUN = function(x){tapply(dfUsing[, x], 
                                                          dfUsing[, treatVars], 
                                                          mean, na.rm = T)})), digits = 2)
# Note that you need to run balTab before the balance test because you may need to switch signs of variables for FDR correction

## Balance Test

balTest <- sapply(balUse, FUN = function(x){
  modSum <- summary(lm(make_equation(x, treatVars), data = dfUsing))
  return(modSum$coefficients[grep(treatVars, rownames(modSum$coefficients)), 4])
})

balFinal <- as.data.frame(round(cbind(balTab, balTest, p.adjust(balTest, method = "holm")), digits = 2))
colnames(balFinal) <- c("Aid", "Oil", 
                        "p-value", "Holm p")
rownames(balFinal) <- balNames


### TABLE D11. Output
stargazer(balFinal, summary = F, type = "latex")

## There is imbalance in the the trust in MP and quality of public goods
## measures even after FWER. Quality of public goods is already in as
## a control covariate, so just need to include trust

## Original result

print(controlVars)
results <- quick_lm(dep.vars = depVars, 
                    dep.names = depNames,
                    ind.vars = c(controlVars, feVars, treatVar), 
                    data = dfUsing, 
                    keep.vars.tab = treatVar,
                    keep.vars.plot = treatVar,
                    inc.plot = F, 
                    subset.by = "dataset", 
                    stand.vars = depVars, 
                    se_type = "CR2",
                    cluster = sym("sbj_unique")) #
results$table

## Result without poverty and quality of public services

controlNew <- controlVars[!controlVars %in% c("poverty_avg", "services_avg")]
results <- quick_lm(dep.vars = depVars, 
                    dep.names = depNames,
                    ind.vars = c(controlNew, feVars, treatVar), 
                    data = dfUsing, 
                    keep.vars.tab = treatVar,
                    keep.vars.plot = treatVar,
                    inc.plot = F, 
                    subset.by = "dataset", 
                    stand.vars = depVars, 
                    se_type = "CR2",
                    cluster = sym("sbj_unique")) 
results$table ## Actually less significant w/o them

