gc(); rm(list = ls()); set.seed(12345)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) # Note: if you are not using R Studio this command will not work, set WD to source file location manually
require(stargazer)
source("../../function.R") 
load("../../data/final/field_data_final.RData") 

dfList <- ugField
balUse <- c("ptc_age", "ptc_edu", "ptc_vote_bin", "ptc_female", 
            "services_avg", "ptc_income_total_log")
balNames <- c("Age", "Education", "Voted in Prior Election", 
              "Female", "Quality of Public Goods", "Log Total Income")

treatVars <- "treat_factor"
balTab <- round(t(sapply(balUse, FUN = function(x){tapply(dfList[, x], dfList[, treatVars], mean, na.rm = T)})), digits = 2)
# Note that you need to run balTab before the balance test because you may need to switch signs of variables for FDR correction

## Balance Test
balTest <- sapply(balUse, FUN = function(x){
  modSum <- summary(lm(make_equation(x, treatVars), data = dfList))
  return(pf(modSum$fstatistic[1], # This is the f statistic object, pf is the cumulative distribution function of the f statistic and returns the p value
            modSum$fstatistic[2], 
            modSum$fstatistic[3], 
            lower.tail = F))
})


balFinal <- as.data.frame(round(cbind(balTab, balTest, p.adjust(balTest, method = "holm")), digits = 2))
colnames(balFinal) <- c("Aid Info", "Oil Info", "Pure Control", 
                        "F-test p", "Holm p")
rownames(balFinal) <- balNames


### TABLE D13. Output
stargazer(balFinal, summary = F, type = "latex")

