gc(); rm(list = ls()); set.seed(12345)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) # Note: if you are not using R Studio this command will not work, set WD to source file location manually
require(stargazer)
source("../../function.R") 
load("../../data/final/surveyexp_data_final.RData") 

dfList <- dfList$Uganda

numSbj <- tapply(dfList$enum_id, dfList$enum_id, length)
enumKeep <- names(numSbj[numSbj >= 2])
dfList <- dfList[dfList$enum_id %in% enumKeep, ]
balUse <- c("age", "edu_self", "pov_water", "pov_food", "vote", "female", "avg_services")
balNames <- c("Age", "Education", "How Often Gone Without Water", 
              "How Often Gone Without Food", 
              "Voted in Prior Election", "Female", "Quality of Public Goods")
dfList <- mutate(dfList, treatVars = ifelse((dfList$aid==0),"oil","aid"))
treatVars <- "treatVars"
balTab <- round(t(sapply(balUse, FUN = function(x){tapply(dfList[, x], dfList[, treatVars], mean, na.rm = T)})), digits = 2)
# Note that you need to run balTab before the balance test because you may need to switch signs of variables for FDR correction

## Balance Test

balTest <- sapply(balUse, FUN = function(x){
  modSum <- summary(lm(make_equation(x, treatVars), data = dfList))
  return(modSum$coefficients[grep("treatVars", rownames(modSum$coefficients)), 4])
})

balFinal <- as.data.frame(round(cbind(balTab, balTest, p.adjust(balTest, method = "holm")), digits = 2))
colnames(balFinal) <- c("Aid", "Oil", 
                        "p-value", "Holm p")
rownames(balFinal) <- balNames


### TABLE D3. Output
stargazer(balFinal, summary = F, type = "latex")

