gc(); rm(list = ls()); set.seed(12345)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) # Note: if you are not using R Studio this command will not work, set WD to source file location manually
require(magrittr)
require(plyr)
require(dplyr)
require(stringr)
require(data.table)
require(kableExtra)
source("../../function.R")
load("../../data/final/surveyexp_data_final.RData")

######################### ESTIMATE #####################################

## Get rid of enumerators with too few observations so you can use enum FE 
for(i in 1:length(dfList)){
  numSbj <- tapply(dfList[[i]]$enum_id, dfList[[i]]$enum_id, length)
  enumKeep <- names(numSbj[numSbj >= 2])
  print(sum(!dfList[[i]]$enum_id %in% enumKeep)) # This is the number of observations we lose
  dfList[[i]] <- dfList[[i]][dfList[[i]]$enum_id %in% enumKeep, ]
}

results <- quick_lm(dep.vars = actionVars, 
                    dep.names = actionNames,
                    ind.vars = c(controlVars, feVars, treatVar), 
                    data = dfList, 
                    data.names = names(dfList),
                    keep.vars.tab = treatVar,
                    keep.vars.plot = treatVar,
                    inc.plot = F, 
                    subset.by = "dataset", 
                    stand.vars = "non-binary") # note that by default the standard error will be HC2, you can change it by specifying "se_type = " as an argument in the quick_lm() function. It will be passed to the lm_robust() function

surveyExp <- results
save(list = c("surveyExp"), file = "../../results/maintext/surveyExp.RData")

## Table and plot

results$table <- results$table[order(results$table$outcome),]
ExpInc <- c("Pooled", "Ghana", "Uganda")
dfAction <- results$table
dfAction$dataset <- factor(dfAction$dataset, 
                           levels = rev(c("Pooled", "Ghana", "Uganda"))) 
dfAction$outcome <- factor(dfAction$outcome, 
                           levels = rev(depNames))
kable(dfAction[c(1,2,4,5,7)], digits = 3, "rst")
dfPlot <- results$table
dfPlot$Experiment <- factor(dfPlot$dataset, 
                             levels = rev(c("Pooled", "Ghana", "Uganda"))) 
dfPlot$outcome <- factor(dfPlot$outcome, 
                          levels = rev(levels(results$table$outcome))) # You can manipulate the order of the dvs etc when plotted by making them factor variables and then setting the level order equal to the order you want them plotted in. Note that ggplot will order from bottom to top, so if "action_avg" is the first level then it will be plotted at the very bottom
pAction <- ggplot(dfPlot, aes(y = estimate, x = outcome, colour = Experiment)) + 
  geom_linerange(aes(x = outcome, ymin = conf.low,
                     ymax = conf.high, size = I(10)),
                 lwd = 1, linetype = 1, position = position_dodge(width = 3/4)) +
  geom_linerange(aes(x = outcome, ymin = estimate - std.error*qnorm(0.95),
                     ymax = estimate + std.error*qnorm(0.95), size = I(10)),
                 lwd = 1.8, linetype = 1, position = position_dodge(width = 3/4)) +
  geom_pointrange(aes( y = estimate, x = outcome, ymin =  conf.low,
                       ymax = conf.high),
                  lwd = 0.55, position = position_dodge(width = 3/4),
                  shape = 21, fill = "WHITE") + 
  geom_hline(yintercept = 0, color = "grey0", linetype = 2, lwd = 0.5) +
  coord_flip() +  xlab("") + theme_custom() +
  #ggtitle("'Action' Family Dependent Variables") +
  theme(legend.position = c(.86, .18), plot.title = element_text(hjust = 0, vjust = 2.12), 
        legend.text = element_text(size=12), axis.text.y = (element_text(face = c("plain", "plain", "plain", 
                                                                                  "plain", "plain", "plain", 
                                                                                  "plain", "plain", "plain", "bold")))) + 
  ylab("Change in Standard Deviation Units") +
  scale_color_manual(values = c("gray67", "gray45", "grey0"), guide = guide_legend(reverse = TRUE)) + 
  ylim(-.35, .35)

(pFinal <- pAction + annotate("rect", ymin = 1.5*min(dfPlot$conf.low[1:3]), 
                              ymax = 1.5*max(dfPlot$conf.high[1:3]), 
                              xmin = 9.5, xmax = 10.5, 
                              alpha = 0.1, fill = "black"))

pdf(file = "../../figures/maintext/fig1.pdf", height = 6, width = 10)
print(pFinal)
dev.off()



