gc(); rm(list = ls()); set.seed(12345)
setwd(dirname(rstudioapi::getActiveDocumentContext()$path)) # Note: if you are not using R Studio this command will not work, set WD to source file location manually
require(magrittr)
require(plyr)
require(dplyr)
require(stringr)
require(data.table)
require(patchwork)
require(ggthemes)
require(kableExtra)
source("../../function.R")

load("../../data/final/field_data_final.RData")

incTreat <- c("Aid Info", "Oil Info")
dfExp <- ugField[ugField$treat_factor %in% incTreat, ]
enumObs <- tapply(dfExp$enum_enumerator, dfExp$enum_enumerator, length)
# Drop any data by enumerators with not enough observations
rmEnum <- names(enumObs[enumObs <= 2])
dfUsing <- dfExp[!dfExp$enum_enumerator %in% rmEnum, ]
treatVar <- c("aid_info")
results <- quick_lm(data = dfUsing, 
                    dep.vars = depVars, 
                    dep.names = depNames,
                    ind.vars = c(treatVar, controlVars), 
                    keep.vars.tab = treatVar)

## Save results object to be used in Table 1

fieldExp <- results
save(list = c("fieldExp"), file = "../../results/maintext/fieldExp.RData")

## Table and plot

require('texreg')
dfRes <- results$table
dfRes$outcome <- factor(dfRes$outcome, 
                        levels = rev(depNames))
roundVars <- c('estimate', 'std.error', 'p.value')
dfRes[,roundVars] <- round(dfRes[, roundVars], digits = 3)
colsInc <- c('outcome', 'estimate', 'std.error', 'p.value')
kable(dfRes[, colsInc], digits = 3, "rst")
dfPlot <- dfRes
(pExp <- ggplot(dfPlot, aes(y = estimate, x = outcome)) + 
    geom_linerange(aes(x = outcome, ymin = conf.low,
                       ymax = conf.high, size = I(10)),
                   lwd = 1, linetype = 1, position = position_dodge(width = 1/2)) +
    geom_linerange(aes(x = outcome, ymin = estimate - std.error*qnorm(0.95),
                       ymax = estimate + std.error*qnorm(0.95), size = I(10)),
                   lwd = 1.8, linetype = 1, position = position_dodge(width = 1/2)) +
    geom_pointrange(aes( y = estimate, x = outcome, ymin =  conf.low,
                         ymax = conf.high),
                    lwd = 0.65, position = position_dodge(width = 1/2),
                    shape = 21, fill = "WHITE") + 
    geom_hline(yintercept = 0, color = "grey0", linetype = 2, lwd = 0.5) +
    coord_flip() +  
    xlab(" ") + 
    ylab("Change in Proportion of Subjects Taking Action \n (Baseline = Oil Information)") +
    theme_custom(axis_text_size = 12) + 
    theme(plot.title = element_text(size = 14, hjust = 0, vjust = 2.12)) + 
    ylim(-0.2, 0.2) + ggtitle("Survey-Based Field Experiment"))

pdf("../../figures/maintext/fig3.pdf", height = 6, width = 8)
print(pExp)
dev.off()


